//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Core;

public class AttributeRow {
    private DSCAttribute attribute;
    public DSCAttribute Attribute {
        get { return attribute; }
    }

    private ProductAttributeValue value;
    public ProductAttributeValue Value {
        get { return value; }
    }

    public AttributeRow() {
        this.attribute = new DSCAttribute();
        this.value = new ProductAttributeValue(null, null, null, 0);
    }

    public AttributeRow(DSCAttribute attribute, ProductAttributeValue value) {
        this.attribute = attribute;
        this.value = value;
    }
}

public partial class Admin_Controls_ProductAttribute : System.Web.UI.UserControl {
    private bool readOnly = true;
    public bool ReadOnly {
        get { return readOnly; }
        set { readOnly = value; }
    }

    private int startRows = 10;
    public int StartRow {
        get { return startRows; }
        set { startRows = value; }
    }

    private int incrementalRows = 5;
    public int IncrementalRows {
        get { return incrementalRows; }
        set { incrementalRows = value; }
    }

    private List<ProductAttribute> productAttributes;
    public List<ProductAttribute> ProductAttributes {
        get {
            Dictionary<DSCAttribute, List<ProductAttributeValue>> attributeMap = new Dictionary<DSCAttribute, List<ProductAttributeValue>>();
            foreach (AttributeRow row in GetAttributeRowsFromControls(true)) {
                if (!attributeMap.ContainsKey(row.Attribute))
                    attributeMap.Add(row.Attribute, new List<ProductAttributeValue>());
                List<ProductAttributeValue> values = attributeMap[row.Attribute];
                values.Add(row.Value);
            }
            List<ProductAttribute> productAttributeList = new List<ProductAttribute>();
            foreach (DSCAttribute attribute in attributeMap.Keys) {
                productAttributeList.Add(new ProductAttribute(attribute, attributeMap[attribute]));
            }
            return productAttributeList;
        }
        set { productAttributes = value; }
    }

    private List<DSCAttribute> allAttributes = null;
    private List<DSCAttribute> AllAttributes {
        get {
            if (null == allAttributes) {
                allAttributes = DSCAttribute.GetAll();
            }
            return allAttributes;
        }
    }

    protected void Page_Load(object sender, EventArgs e) {
        if (!IsPostBack) {
            if ((null == AllAttributes) || (0 == AllAttributes.Count)) {
                pnlEmptyAttribute.Visible = true;
                pnlAttribute.Visible = false;
            }
        }
    }

    protected override void OnDataBinding(EventArgs e) {
        base.OnDataBinding(e);

        if (readOnly) {
            List<AttributeRow> rows = new List<AttributeRow>();
            if (null != productAttributes) {
                foreach (ProductAttribute pa in productAttributes) {
                    foreach (ProductAttributeValue pav in pa.Values) {
                        rows.Add(new AttributeRow(pa.Attribute, pav));
                    }
                }
            }
            rptBulkEdit.Visible = false;
            rptDisplay.Visible = true;
            rptDisplay.DataSource = rows;
            rptDisplay.DataBind();
        } else {
            List<AttributeRow> rows = new List<AttributeRow>();
            if (null != productAttributes) {
                foreach (ProductAttribute pa in productAttributes) {
                    foreach (ProductAttributeValue pav in pa.Values) {
                        rows.Add(new AttributeRow(pa.Attribute, pav));
                    }
                }
            }
            PadEmptyRows(rows);

            rptDisplay.Visible = false;
            rptBulkEdit.Visible = true;
            rptBulkEdit.DataSource = rows;
            rptBulkEdit.DataBind();
        }
    }

    private void PadEmptyRows(List<AttributeRow> rows) {
        if (rows.Count < startRows) {
            AddEmptyRows(rows, startRows - rows.Count);
        } else {
            int over = (rows.Count % startRows) % incrementalRows;
            AddEmptyRows(rows, incrementalRows - over);
        }
    }

    private void AddEmptyRows(List<AttributeRow> rows, int numberOfRows) {
        for (int i = 0; i < numberOfRows; i++)
            rows.Add(new AttributeRow());
    }

    private List<AttributeRow> GetAttributeRowsFromControls(bool ignoreEmptyAttributeValue) {
        List<AttributeRow> rows = new List<AttributeRow>();
        List<DSCAttribute> attributes = DSCAttribute.GetAll();
        Dictionary<int, DSCAttribute> attributesMap = new Dictionary<int,DSCAttribute>();
        foreach (DSCAttribute attribute in attributes) {
            attributesMap.Add(attribute.AttributeId, attribute);
        }

        foreach (RepeaterItem item in rptBulkEdit.Items) {
            TextBox txtAttributeValue = (TextBox)item.FindControl("txtAttributeValue");
            if ((!ignoreEmptyAttributeValue) ||
                (!string.IsNullOrEmpty(txtAttributeValue.Text))) {
                DropDownList ddlAttributes = (DropDownList)item.FindControl("ddlAttributes");
                Controls_UploadImages iupSelectionValueImage = (Controls_UploadImages)item.FindControl("iupSelectionValueImage");
                Controls_NumberTextBox ntbQuantity = (Controls_NumberTextBox)item.FindControl("ntbQuantity");
                Controls_DecimalTextBox dtbAttributePriceAdjustment = (Controls_DecimalTextBox)item.FindControl("dtbAttributePriceAdjustment");
                decimal priceAdjustment = string.IsNullOrEmpty(dtbAttributePriceAdjustment.Text) ? 0 : dtbAttributePriceAdjustment.MoneyValue;
                rows.Add(new AttributeRow(attributesMap[int.Parse(ddlAttributes.SelectedValue)], 
                    new ProductAttributeValue(iupSelectionValueImage.ImageId, txtAttributeValue.Text, 
                        Utils.ConvertNullableFromString<int?>(ntbQuantity.Text) , priceAdjustment)));
            }
        }
        return rows;
    }

    protected void btnAddRow_Click(object sender, EventArgs e) {
        List<AttributeRow> rows = GetAttributeRowsFromControls(false);
        AddEmptyRows(rows, incrementalRows);
        rptBulkEdit.DataSource = rows;
        rptBulkEdit.DataBind();
    }

    protected void btnDelete_Command(object sender, CommandEventArgs e) {
        int index = int.Parse(e.CommandArgument.ToString());
        List<AttributeRow> rows = GetAttributeRowsFromControls(false);
        rows.RemoveAt(index);
        rptBulkEdit.DataSource = rows;
        rptBulkEdit.DataBind();
    }

    protected void rptBulkEdit_ItemDataBound(object sender, RepeaterItemEventArgs e) {
        if ((e.Item.ItemType == ListItemType.Item) ||
            (e.Item.ItemType == ListItemType.AlternatingItem)){
            AttributeRow ar = (AttributeRow)e.Item.DataItem;
            DropDownList ddlAttributes = (DropDownList)e.Item.FindControl("ddlAttributes");
            ddlAttributes.DataSource = AllAttributes;
            ddlAttributes.DataBind();
            WebUtils.SetDropDownListSelected(ddlAttributes, ar.Attribute.AttributeId.ToString());
            Button btnDelete = (Button)e.Item.FindControl("btnDelete");
            btnDelete.CommandArgument = e.Item.ItemIndex.ToString();
        }
    }

    protected void cvdAttributeValue_ServerValidate(object source, ServerValidateEventArgs args) {
        Control parent = ((Control)source).NamingContainer;
        TextBox txtAttributeValue = (TextBox)parent.FindControl("txtAttributeValue");
        Controls_UploadImages iupSelectionValueImage = (Controls_UploadImages)parent.FindControl("iupSelectionValueImage");
        Controls_NumberTextBox ntbQuantity = (Controls_NumberTextBox)parent.FindControl("ntbQuantity");
        Controls_DecimalTextBox dtbAttributePriceAdjustment = (Controls_DecimalTextBox)parent.FindControl("dtbAttributePriceAdjustment");
        decimal priceAdjustment = 0;
        args.IsValid = !string.IsNullOrEmpty(txtAttributeValue.Text) ||
            ((null == iupSelectionValueImage.ImageId) &&
              string.IsNullOrEmpty(ntbQuantity.Text) &&
              decimal.TryParse(dtbAttributePriceAdjustment.Text, out priceAdjustment) &&
              (0 == priceAdjustment));
    }
}
