//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Specialized;
using System.Collections.Generic;
using System.Text;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Core;

public partial class Admin_Controls_ProductCategoryMap : System.Web.UI.UserControl {
    private Product product = null;
    private bool readOnly = true;
    private int defaultCategoryId = 0;

    public Product Product {
        get { return product; }
        set { product = value; }
    }
    public bool ReadOnly {
        get { return readOnly; }
        set { readOnly = value; }
    }
    public int DefaultCategoryId {
        get { return defaultCategoryId; }
        set { defaultCategoryId = value; }
    }
    public ICollection<CategoryInformation> Categories {
        get {
            MergeIsFeatureValues();
            return categoryInformations.Values; }
    }

    private Dictionary<int, CategoryInformation> categoryInformations {
        get { return (Dictionary<int, CategoryInformation>)ViewState["category_Informations"]; }
        set { ViewState["category_Informations"] = value; }
    }

    protected void Page_PreRender(object sender, EventArgs e) {
        if (null == categoryInformations) {
            if (null == product) {
                categoryInformations = new Dictionary<int, CategoryInformation>();
                if (defaultCategoryId > 0) {
                    Category c = Category.GetCategories(defaultCategoryId, 1)[0];
                    categoryInformations.Add(defaultCategoryId, new CategoryInformation(c.FullPath, defaultCategoryId, false, c.FeaturedSortOrder));
                }
            } else {
                categoryInformations = CategoryInformation.GetFromCategory(product.GetCategories());
            }
        }

        if (!readOnly) {
            Category[] categories = Category.GetAll(null, true);
            List<Category> categoriesToAdd = new List<Category>();
            foreach (Category c in categories) {
                if (!categoryInformations.ContainsKey(c.CategoryId)) {
                    categoriesToAdd.Add(c);
                }
            }
            ddlCategoryToAdd.DataSource = categoriesToAdd;
            ddlCategoryToAdd.DataBind();
            btnAdd.Enabled = ddlCategoryToAdd.Items.Count > 0;

            MergeIsFeatureValues();
        }
        gvwProductCategories.Columns[3].Visible = !readOnly;
        gvwProductCategories.DataSource = categoryInformations.Values;
        gvwProductCategories.DataBind();
    }

    private void MergeIsFeatureValues() {
        //read isFeature checked status into categoryInformations
        foreach (GridViewRow row in gvwProductCategories.Rows) {
            CheckBox chkFeatured = (CheckBox)row.FindControl("chkFeatured");
            Controls_NumberTextBox ntbSortOrder = (Controls_NumberTextBox)row.FindControl("ntbSortOrder");

            int id = (int)gvwProductCategories.DataKeys[row.RowIndex]["Id"];
            if (categoryInformations.ContainsKey(id)) {
                categoryInformations[id].IsFeatured = chkFeatured.Checked;
                categoryInformations[id].FeatureSortOrder = int.Parse(ntbSortOrder.Text);
            }
        }
    }

    protected void gvwProductCategories_RowDataBound(object sender, GridViewRowEventArgs e) {
        if ((!readOnly) && (DataControlRowType.DataRow == e.Row.RowType)) {
            Button btnDelete = (Button)e.Row.FindControl("btnDelete");
            btnDelete.Visible = true;
            btnDelete.Enabled = categoryInformations.Count > 1;
            CheckBox chkFeatured = (CheckBox)e.Row.FindControl("chkFeatured");
            chkFeatured.Enabled = true;
            Controls_NumberTextBox ntbSortOrder = (Controls_NumberTextBox)e.Row.FindControl("ntbSortOrder");
            ntbSortOrder.Enabled = true;
        }
    }

    protected void gvwProductCategories_RowDeleting(object sender, GridViewDeleteEventArgs e) {
        int id = (int)gvwProductCategories.DataKeys[e.RowIndex]["Id"];
        categoryInformations.Remove(id);
    }

    protected void btnAdd_Click(object sender, EventArgs e) {
        int id = int.Parse(ddlCategoryToAdd.SelectedItem.Value);
        categoryInformations.Add(id, new CategoryInformation(ddlCategoryToAdd.SelectedItem.Text, id, false, 0));
    }
}
