//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Core;

public class ProductSelectedEventArgs : EventArgs {
    public int ProductId;

    public ProductSelectedEventArgs(int productId) {
        ProductId = productId;
    }
}
public delegate void ProductSelectedEventHandler(object sender, ProductSelectedEventArgs e);


public partial class Admin_Catalog_Controls_ProductSelector : System.Web.UI.UserControl {
    public bool PostBackOnSelect {
        get {
            if (null == ViewState["PostBackOnSelect"])
                return false;
            return (bool)ViewState["PostBackOnSelect"]; 
        }
        set { ViewState["PostBackOnSelect"] = value; }
    }

    public event ProductSelectedEventHandler Selected = null;

    public List<int> SelectedProductIds {
        get {
            List<int> ids = new List<int>();
            foreach (GridViewRow row in gvwProducts.Rows) {
                CheckBox chkSelect = (CheckBox)row.FindControl("chkSelect");
                if (chkSelect.Checked) {
                    ids.Add((int)gvwProducts.DataKeys[row.RowIndex]["ProductId"]);
                }
            }
            return ids;
        }
    }

    protected void Page_Load(object sender, EventArgs e) {
        if (!IsPostBack) {
            txtSearchProduct.Attributes.Add("onkeydown", "if ((event.which && event.which == 13) || (event.keyCode && event.keyCode == 13)){ $get('" +
                btnSearchProduct.ClientID + "').click(); return false;} else return true;");
        } else {
            foreach (GridViewRow row in gvwProducts.Rows) {
                CheckBox chkSelect = (CheckBox)row.FindControl("chkSelect");
                if (chkSelect.Checked) {
                    OnSelected(new ProductSelectedEventArgs((int)gvwProducts.DataKeys[row.RowIndex]["ProductId"]));
                }
            }
        }
    }

    protected void cvdSearch_ServerValidate(object source, ServerValidateEventArgs args) {
        args.IsValid = !(("0" == ddlCategory.SelectedValue) && string.IsNullOrEmpty(txtSearchProduct.Text));
    }

    protected void btnSearchProduct_Click(object sender, EventArgs e) {
        gvwProducts.PageIndex = 0;
    }

    protected virtual void OnSelected(ProductSelectedEventArgs e) {
        if (null != Selected) {
            Selected(this, e);
        }
    }

    public void Clear() {
        txtSearchProduct.Text = string.Empty;
        ddlCategory.SelectedIndex = 0;
        gvwProducts.DataBind();
    }
}
