//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.IO;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Core;

public partial class Controls_UploadImages : System.Web.UI.UserControl {
    private bool readOnly = true, multiImages = true, showDefaultImageColumn = true, showTitle = true, showEmptyImage = true;
    private ProductImage[] inputImages = null;
    private int bulkImageAddCount = 10;
   
    public bool ReadOnly {
        get { return readOnly; }
        set { readOnly = value; }
    }
    public bool ShowEmptyImage {
        get { return showEmptyImage; }
        set { showEmptyImage = value; }
    }
    public bool MultiImages {
        get { return multiImages; }
        set { multiImages = value; }
    }
    public bool ShowDefaultImageColumn {
        get { return showDefaultImageColumn; }
        set { showDefaultImageColumn = value; }
    }
    public bool ShowTitle {
        get { return showTitle; }
        set { showTitle = value; }
    }
    private Dictionary<int, ProductImage> images {
        get { return (Dictionary<int, ProductImage>)ViewState["images"]; }
        set { ViewState["images"] = value; }
    }
    public ProductImage[] Images {
        get {
            MergeTitleValues();
            return new List<ProductImage>(images.Values).ToArray();
        }
        set { 
            inputImages = value;
            PopulateImagesInViewState();
        }
    }
    public int? ImageId {
        get {
            if (0 == Images.Length)
                return null;
            return Images[0].ImageId; 
        }
        set {
            if (null != value) {
                inputImages = new ProductImage[1];
                inputImages[0] = new ProductImage((int)value);
            } else {
                images = null;
            }
            PopulateImagesInViewState();
        }
    }
    public int BulkAddImageCount {
        get { return bulkImageAddCount; }
        set { bulkImageAddCount = value; }
    }
    private string javascriptMethodName {
        get { return this.ClientID + "_OnImageUploaded"; }
    }

    private void MergeTitleValues() {
        foreach (GridViewRow row in gvwImages.Rows) {
            TextBox txtTitle = (TextBox)row.FindControl("txtTitle");
            int imageId = (int)gvwImages.DataKeys[row.RowIndex]["ImageId"];
            if (images.ContainsKey(imageId)) // after the existing image is updated, the old imageid doesn't exist any more.
                images[imageId].Title = txtTitle.Text;
        }
    }

    protected void Page_PreRender(object sender, EventArgs e) {
        btnCancel.ImageUrl = FileController.GetFileUrl("close.gif");
        btnAddCancel.ImageUrl = FileController.GetFileUrl("close.gif");

        PopulateImagesInViewState();
        MergeTitleValues();

        gvwImages.DataSource = images.Values;
        gvwImages.DataBind();

        Image imgEmpty = (Image)UpdatePanelImages.FindControl("imgEmpty");
        int? emptyImageId = null;
        imgEmpty.ImageUrl = FileController.GetImageUrl(emptyImageId, 80, 60);
        imgEmpty.Visible = showEmptyImage && ((null == images) || (0 == images.Count));

        btnAddImage.Visible = (!readOnly) && (multiImages || gvwImages.Rows.Count == 0);

        int imageAddCount = multiImages ? bulkImageAddCount : 1;
        ifmImageAdd.Attributes.Add("src", string.Format("{0}?c={1}&m={2}", SiteNavigation.UploadFilesPage, imageAddCount, javascriptMethodName));
        ifmImageAdd.Attributes.Add("style", string.Format("width:100%; height:{0}px;", 150 + imageAddCount * 10));

        string script = "function " + javascriptMethodName + "(imageIds, oldImageId) {\n" +
                        "var btnCancel = document.getElementById('" + btnCancel.ClientID + "');\n" +
                        "btnCancel.click();\n" +
                        "var btnAddCancel = document.getElementById('" + btnAddCancel.ClientID + "');\n" +
                        "btnAddCancel.click();\n" +
                        "var hidImageIds = document.getElementById('" + ((HiddenField)UpdatePanelImages.FindControl("hidImageIds")).ClientID + "');\n" +
                        "hidImageIds.value = imageIds;" +
                        "var hidOldImageId = document.getElementById('" + ((HiddenField)UpdatePanelImages.FindControl("hidOldImageId")).ClientID + "');\n" +
                        "hidOldImageId.value = oldImageId;" +
                        "var btnHiddenAdd = document.getElementById('" + ((Button)UpdatePanelImages.FindControl("btnHiddenAdd")).ClientID + "');\n" +
                        "btnHiddenAdd.click();" +
                        "}";
        ScriptManager.RegisterClientScriptBlock(this, this.GetType(), javascriptMethodName, script, true);

        gvwImages.Columns[1].Visible = showTitle;
        gvwImages.Columns[2].Visible = showDefaultImageColumn;
        gvwImages.Columns[3].Visible = !readOnly;
        if (null != gvwImages.HeaderRow)
            gvwImages.HeaderRow.Visible = showTitle;
    }

    private void PopulateImagesInViewState() {
        if (null == images) {
            images = new Dictionary<int, ProductImage>();
            if (null != inputImages) {
                foreach (ProductImage pi in inputImages) {
                    images.Add(pi.ImageId, pi);
                }
            }
        }
    }

    protected void gvwImages_RowDeleting(object sender, GridViewDeleteEventArgs e) {
        images.Remove((int)gvwImages.DataKeys[e.RowIndex]["ImageId"]);
    }

    protected void gvwImages_RowDataBound(object sender, GridViewRowEventArgs e) {
        if (e.Row.RowType == DataControlRowType.DataRow) {
            ProductImage pi = (ProductImage)e.Row.DataItem;
            Button btnUpdate = (Button)e.Row.FindControl("btnUpdate");
            if (null != btnUpdate) {
                string setImageUploadUrl = string.Format("$get('{0}').src='{1}?oldimageid={2}&m={3}';{4}.click();return false;",
                    ifmImageUpload.ClientID, SiteNavigation.UploadFilesPage, pi.ImageId, javascriptMethodName,
                    ((Button)UpdatePanelImages.FindControl("btnUpdateImage")).ClientID);
                btnUpdate.OnClientClick = setImageUploadUrl;
            }
            RadioButton rdbDefault = (RadioButton)e.Row.FindControl("rdbDefault");
            rdbDefault.Enabled = !readOnly;
        }
    }

    protected void rdbDefault_CheckedChanged(object sender, EventArgs e) {
        foreach (GridViewRow row in gvwImages.Rows) {
            RadioButton rdbDefault = (RadioButton)row.FindControl("rdbDefault");
            HiddenField hidImageId = (HiddenField)row.FindControl("hidImageId");
            int imageId = int.Parse(hidImageId.Value);
            if (rdbDefault == sender) {
                rdbDefault.Checked = false;
                images[imageId].IsDefault = true;
            } else if (rdbDefault.Checked) {
                images[imageId].IsDefault = false;
            }
        }
    }

    protected void btnHiddenAdd_Click(object sender, EventArgs e) {
        HiddenField hidImageIds = (HiddenField)UpdatePanelImages.FindControl("hidImageIds");
        int[] imageIds = Utils.ParseIds(hidImageIds.Value);
        HiddenField hidOldImageId = (HiddenField)UpdatePanelImages.FindControl("hidOldImageId");
        int oldImageId = int.Parse(hidOldImageId.Value);
        hidOldImageId.Value = ""; //reset it after reading
        if (oldImageId > 0) { // update
            ProductImage pi = images[oldImageId];
            pi.ImageId = imageIds[0];
            images.Remove(oldImageId);
            images.Add(imageIds[0], pi);
        } else { // add new ones
            bool setFirstImageToDefault = images.Count == 0;
            foreach (int imageId in imageIds) {
                ProductImage pi = new ProductImage(imageId, null);
                if (setFirstImageToDefault) {
                    pi.IsDefault = true;
                    setFirstImageToDefault = false;
                }
                images.Add(imageId, pi);
            }
        }
    }
}
