﻿//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;

using DotShoppingCart.OpenSource.Core;

public partial class Admin_Store_MenuEdit : DSCPage {
    private int blockId;
    private string returnUrl, title, url;

    private MenuData menuData = MenuData.Default;
    private List<IndexedMenuItem> menus {
        get { return (List<IndexedMenuItem>)ViewState["menus"]; }
        set { ViewState["menus"] = value; }
    }

    private Controls_ComboBox cbbUrl {
        get { return (Controls_ComboBox)dvwMenuItem.FindControl("cbbUrl"); }//dvwMenuItem.Rows[1].FindControl("cbbUrl")
    }

    protected void Page_Load(object sender, EventArgs e) {
        blockId = Utils.GetIntParameter("id");
        returnUrl = Utils.GetParameter("returnurl");

        if (!IsPostBack) {
            btnCancel.OnClientClick = string.Format("javascript:window.location.href=\"{0}\";return false;", returnUrl);
            menus = Select();
            BindControls();
            if (null != menuData) {
                txtMenuClass.Text = menuData.MenuClass;
                txtMenuItemClass.Text = menuData.MenuItemClass;
            }
        }
    }

    private void BindControls() {
        rol.DataSource = menus;
        rol.DataBind();
    }

    protected void Page_PreRender(object sender, EventArgs e) {
        lblMessage.Text = dvwMenuItem.CurrentMode == DetailsViewMode.Edit ? "Edit Menu Item" : "Add a Menu Item";
    }

    protected void rol_ItemReorder(object sender, AjaxControlToolkit.ReorderListItemReorderEventArgs e) {
        int start, stop, step;
        if (e.OldIndex > e.NewIndex) {
            start = e.NewIndex;
            stop = e.OldIndex;
            step = 1;
        } else {
            start = e.OldIndex;
            stop = e.NewIndex;
            step = -1;
        }
        for (int i = start; i <= stop; i++) {
            if (i != e.OldIndex)
                menus[i].Index += step;
        }
        menus[e.OldIndex].Index = e.NewIndex;
        menus = menus.OrderBy(m => m.Index).ToList();
        BindControls();
    }

    protected void btnSave_Click(object sender, EventArgs e) {
        List<MenuItemData> menuItems = new List<MenuItemData>();
        foreach (IndexedMenuItem mi in menus) {
            menuItems.Add(new MenuItemData() { Title = mi.Title, Url = mi.Url });
        }

        using (DSCDataContext dc = DBController.GetDataContext()) {
            Block block = dc.Blocks.Single(b => b.BlockId == blockId);
            MenuData data = new MenuData() { 
                MenuClass = txtMenuClass.Text,
                MenuItemClass = txtMenuItemClass.Text
            };
            data.MenuItems = menuItems;
            block.Data = data.ToXElement();
            dc.SubmitChanges();
        }
        Response.Redirect(returnUrl);
    }

    protected void btnCancel_Click(object sender, EventArgs e) {
        dvwMenuItem.ChangeMode(DetailsViewMode.Insert);
        pnlActions.Enabled = rol.Enabled = true;
    }

    protected void rol_DeleteCommand(object sender, AjaxControlToolkit.ReorderListCommandEventArgs e) {
        int index = e.Item.ItemIndex;
        menus.RemoveAt(index);
        for (int i = index; i < menus.Count; i++) {
            menus[i].Index--;
        }
        BindControls();
        dvwMenuItem.ChangeMode(DetailsViewMode.Insert);
    }

    protected void btnEdit_Command(object sender, CommandEventArgs e) {
        int index = int.Parse(e.CommandArgument.ToString());
        pnlActions.Enabled = rol.Enabled = false;
        dvwMenuItem.ChangeMode(DetailsViewMode.Edit);
        dvwMenuItem.DataSource = new IndexedMenuItem[] { menus[index] };
        dvwMenuItem.DataBind();
    }

    protected void dvwMenuItem_ItemUpdating(object sender, DetailsViewUpdateEventArgs e) {
        if (IsValid) {
            GetValuesFromControls();
            IndexedMenuItem mi = menus[(int)dvwMenuItem.DataKey["Index"]];
            mi.Title = title;
            mi.Url = url;
            dvwMenuItem.ChangeMode(DetailsViewMode.Insert);
            pnlActions.Enabled = rol.Enabled = true;
            BindControls();
        }
    }

    protected void dvwMenuItem_ItemInserting(object sender, DetailsViewInsertEventArgs e) {
        if (IsValid) {
            GetValuesFromControls();
            menus.Add(new IndexedMenuItem() {
                Index = menus.Count,
                Title = title,
                Url = url
            });
            ClearControlValues();
            BindControls();
        }
    }

    private void GetValuesFromControls() {
        TextBox txtTitle = (TextBox)dvwMenuItem.FindControl("txtTitle");
        title = txtTitle.Text;
        url = cbbUrl.Text;
    }

    private void ClearControlValues() {
        ((TextBox)dvwMenuItem.FindControl("txtTitle")).Text = string.Empty;
        cbbUrl.Text = string.Empty;
    }

    private List<IndexedMenuItem> Select() {
        Block block = Block.GetById(blockId);
        if (null != block.Data) {
            menuData = Utils.FromXml<MenuData>(block.Data.ToString());
            if (null != menuData.MenuItems)
                return ConvertMenuItems(menuData.MenuItems);
        }
        return new List<IndexedMenuItem>();
    }

    private List<IndexedMenuItem> ConvertMenuItems(List<MenuItemData> menuItems) {
        List<IndexedMenuItem> list = new List<IndexedMenuItem>();
        int index = 0;
        foreach (MenuItemData mi in menuItems) {
            list.Add(new IndexedMenuItem() {
                Index = index,
                Title = mi.Title,
                Url = mi.Url
            });
            index++;
        }
        return list;
    }

    [Serializable]
    private class IndexedMenuItem {
        public int Index { get; set; }
        public string Title { get; set; }
        public string Url { get; set; }
    }

    protected class InteralPage {
        public string Name { get; set; }
        public string Url { get; set; }

        public static List<InteralPage> GetAll() {
            List<InteralPage> pages;
            //add custom pages
            using (DSCDataContext dc = DBController.GetDataContext()) {
                pages = (from p in dc.DbPages
                         let url = p.Name == "home" ? "~/Default.aspx" : string.Format("~/Page/{0}.aspx", p.Name)
                         select new InteralPage() {
                             Name = p.Name,
                             Url = url
                         }).ToList();
            }
            //add interal pages
            DynamicPageConfigurationSection section = DynamicPageConfigurationSection.GetSection();
            foreach (PathConfigurationElement pathElement in section.Paths) {
                string path = pathElement.Value;
                foreach (PageConfigurationElement pageElement in pathElement.Pages) {
                    if (!pageElement.DirectLinkDisabled) {
                        string pageName = (string.IsNullOrEmpty(path) ? "" : path + "/") + pageElement.Name;
                        pages.Add(new InteralPage() {
                            Name = pageName,
                            Url = string.Format("~/{0}.aspx", pageName)
                        });
                    }
                }
            }
            return pages;
        }
    }
}