//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Runtime.Serialization.Formatters.Binary;
using System.IO;
using System.Text;
using System.Collections.Specialized;

using DotShoppingCart.OpenSource.Shipping;
using DotShoppingCart.OpenSource.Core;

public partial class Admin_Controls_TableBasedShippingConfiguration : CustomUserControl {
    private List<TableBasedShippingMethod> shippingMethods {
        get { return (List<TableBasedShippingMethod>)ViewState["shippingMethods"]; }
        set { ViewState["shippingMethods"] = value;  }
    }
    public override string NewConfiguredValue {
        get { return TableBasedShippingProvider.SerializeShippingMethods(shippingMethods); }
    }

    public override void DataBind() {
        base.DataBind();
        if (null != base.configuredValue) {
            shippingMethods = TableBasedShippingProvider.DeSerializeTaxShippingMethods(base.configuredValue);
            BindControl();
        }
    }

    protected void rptShippingMethods_ItemDataBound(object sender, RepeaterItemEventArgs e) {
        TableBasedShippingMethod method = (TableBasedShippingMethod)e.Item.DataItem;
        Button btnAddShippingRegion = (Button)e.Item.FindControl("btnAddShippingRegion");
        btnAddShippingRegion.Text = string.Format("Add Shipping Region To {0}", method.Name);
        btnAddShippingRegion.OnClientClick = string.Format("javascript:window.location.href=\"{0}?sindex={1}\";return false;",
            SiteNavigation.ShippingRegionEditPage, e.Item.ItemIndex);
    }

    private void BindControl() {
        if (null != shippingMethods) {
            rptShippingMethods.DataSource = shippingMethods;
            rptShippingMethods.DataBind();
        }
    }

    protected void btnDelete_Click(object sender, EventArgs e) {
        shippingMethods.Remove(GetShippingMethod((Control)sender));
        TableBasedShippingProvider.SaveShippingMethods(shippingMethods);
        BindControl();
    }

    protected void editShippingMethod_ShippingMethodSubmitted(object sender, EventArgs e) {
        TableBasedShippingMethod method = GetShippingMethod((Control)sender);
        method.CopyValuesFrom(((Admin_Store_Controls_ShippingMethodEdit)sender).ShippingMethod);
        shippingMethods.Sort(TableBasedShippingMethod.Compare);
        TableBasedShippingProvider.SaveShippingMethods(shippingMethods);
        BindControl();
    }

    private TableBasedShippingMethod GetShippingMethod(Control control) {
        int index = -1;
        foreach (RepeaterItem item in rptShippingMethods.Items) {
            if (item == control.NamingContainer) {
                index = item.ItemIndex;

            }
        }
        return shippingMethods[index];
    }

    protected void addShippingMethod_ShippingMethodSubmitted(object sender, EventArgs e) {
        if (null == shippingMethods)
            shippingMethods = new List<TableBasedShippingMethod>();
        TableBasedShippingMethod method = addShippingMethod.ShippingMethod;
        shippingMethods.Add(method);
        shippingMethods.Sort(TableBasedShippingMethod.Compare);
        TableBasedShippingProvider.SaveShippingMethods(shippingMethods);
        //Continue to add shipping region
        Response.Redirect(string.Format("{0}?sindex={1}", SiteNavigation.ShippingRegionEditPage,
            shippingMethods.IndexOf(method)));
    }

}
