//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Linq;

using DotShoppingCart.OpenSource.Core;
using DotShoppingCart.OpenSource.Shipping;
using AjaxControlToolkit;

public partial class Admin_Configuration_Shipping : DSCPage {
    protected void Page_Load(object sender, EventArgs e) {
        LoadDynamicControls(!IsPostBack);
    }

    private void LoadDynamicControls(bool bind) {
        List<Control> controlsToDataBind = new List<Control>();
        TabContainer tbcShippings = new TabContainer();
        tbcShippings.ID = "tbcShippings";
        foreach (ShippingProvider p in GetShippingProviders()) {
            TabPanel tp = new TabPanel();
            tp.ID = "tab" + p.Name.Replace(" ", "");
            tp.HeaderText = p.Name;
            Admin_Store_Controls_ShippingConfigurationTemplate template = (Admin_Store_Controls_ShippingConfigurationTemplate)LoadControl("Controls/ShippingConfigurationTemplate.ascx");
            tp.ContentTemplate = template;
            template.Provider = p;
            template.ValidationGroup = p.Name;
            controlsToDataBind.Add(template);
            tbcShippings.Tabs.Add(tp);
        }
        tbcShippings.ActiveTabIndex = 0;
        phdTabl.Controls.Add(tbcShippings);
        if (bind) {
            foreach (Control c in controlsToDataBind)
                c.DataBind();
        }
    }

    private List<ShippingProvider> GetShippingProviders() {
        List<ShippingProvider> providers = new List<ShippingProvider>();
        foreach (Type t in Utils.GetProviders("*Shipping*.dll", typeof(ShippingProvider))) {
            object classInstance = Activator.CreateInstance(t);
            providers.Add((ShippingProvider)classInstance);
        }
        // Move TableBasedShippingProvider to the first
        providers.Sort(Compare);
        return providers;
    }

    private static int Compare(ShippingProvider x, ShippingProvider y) {
        if ((x is TableBasedShippingProvider) && (!(y is TableBasedShippingProvider)))
            return -1;

        if ((!(x is TableBasedShippingProvider)) && (y is TableBasedShippingProvider))
            return 1;

        return x.Name.CompareTo(y.Name);
    }
}
