//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Shipping;
using DotShoppingCart.OpenSource.Core;

public partial class Admin_Store_ShippingRegionEdit : DSCPage {
    private int shippingRegionIndex, shippingMethodIndex;
    private bool insert = true;

    protected void Page_Load(object sender, EventArgs e) {
        shippingMethodIndex = Utils.GetIntParameter("sindex");
        shippingRegionIndex = Utils.GetIntParameter("index", -1);
        insert = shippingRegionIndex < 0;
        if (!IsPostBack) {
            lblTitle.Text = (insert ? "Add" : "Edit") + " Shipping Region";
            List<TableBasedShippingMethod> methods = TableBasedShippingProvider.GetShippingMethods();
            TableBasedShippingMethod method = methods[shippingMethodIndex];
            shippingRate.Target = method.Target;

            if (!insert) {
                TableBasedShippingRegion region = method.ShippingRegions[shippingRegionIndex];
                txtName.Text = region.Name;
                configureCondition.Conditions = region.Conditions;
                configureCondition.DataBind();
                shippingRate.Rates = region.Rates;
                shippingRate.DataBind();
            }
        }
    }

    protected void shippingRegionWizard_NextButtonClick(object sender, WizardNavigationEventArgs e) {
        e.Cancel = !Page.IsValid;
    }

    protected void shippingRegionWizard_FinishButtonClick(object sender, WizardNavigationEventArgs e) {
        e.Cancel = !Page.IsValid;
        if (!e.Cancel) {
            TableBasedShippingRegion region = new TableBasedShippingRegion(txtName.Text,
                configureCondition.Conditions, shippingRate.Rates);

            List<TableBasedShippingMethod> methods = TableBasedShippingProvider.GetShippingMethods();
            List<TableBasedShippingRegion> regions = methods[shippingMethodIndex].ShippingRegions;

            if (insert) {
                if (null == regions) {
                    regions = new List<TableBasedShippingRegion>();
                    methods[shippingMethodIndex].ShippingRegions = regions;
                }
                regions.Add(region);
            } else
                regions[shippingRegionIndex] = region;
            TableBasedShippingProvider.SaveShippingMethods(methods);
            Response.Redirect(SiteNavigation.StoreShippingPage);
        }
    }

    protected void btnOk_Click(object sender, EventArgs e) {
        List<Condition> conditions = new List<Condition>();
        txtName.Text = ddlRegions.SelectedItem.Value;
        switch (ddlRegions.SelectedItem.Value) {
            case "All US States":
                conditions.Add(new Condition("Country", ConditionOperator.Equal, "US"));
                configureCondition.Conditions = conditions;
                configureCondition.DataBind();
                break;
            case "Continental US":
                conditions.Add(new Condition("Country", ConditionOperator.Equal, "US"));
                conditions.Add(new Condition("State", ConditionOperator.NotEqual, "AK"));
                conditions.Add(new Condition("State", ConditionOperator.NotEqual, "HI"));
                configureCondition.Conditions = conditions;
                configureCondition.DataBind();
                break;
            case "Alaska":
                conditions.Add(new Condition("Country", ConditionOperator.Equal, "US"));
                conditions.Add(new Condition("State", ConditionOperator.Equal, "AK"));
                configureCondition.Conditions = conditions;
                configureCondition.DataBind();
                break;
            case "Hawaii":
                conditions.Add(new Condition("Country", ConditionOperator.Equal, "US"));
                conditions.Add(new Condition("State", ConditionOperator.Equal, "HI"));
                configureCondition.Conditions = conditions;
                configureCondition.DataBind();
                break;
            case "New York":
                conditions.Add(new Condition("Country", ConditionOperator.Equal, "US"));
                conditions.Add(new Condition("State", ConditionOperator.Equal, "NY"));
                configureCondition.Conditions = conditions;
                configureCondition.DataBind();
                break;
            case "Canada":
                conditions.Add(new Condition("Country", ConditionOperator.Equal, "CA"));
                configureCondition.Conditions = conditions;
                configureCondition.DataBind();
                break;
        }
    }

    protected void cvdDefinition_ServerValidate(object source, ServerValidateEventArgs args) {
        Admin_Controls_ConfigureCondition configureCondition = (Admin_Controls_ConfigureCondition)((Control)source).NamingContainer.FindControl("configureCondition");
        args.IsValid = (null != configureCondition.Conditions) && (configureCondition.Conditions.Count > 0);
    }
}
