//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Tax;
using DotShoppingCart.OpenSource.Core;

public partial class Admin_Configuration_Tax : DSCPage {
    protected void Page_Load(object sender, EventArgs e) {
        providerConfiguration.SectionName = TaxServiceConfigurationSection.SectionName;
        if (!IsPostBack) {
            InitControls();
        }
    }

    private void InitControls() {
        ddlTaxProvider.Items.Clear();

        TaxServiceConfigurationSection pcs = (TaxServiceConfigurationSection)ConfigurationController.SiteConfigurationController.GetSection(TaxServiceConfigurationSection.SectionName);
        foreach (Type t in Utils.GetProviders("*Tax*.dll", typeof(TaxProvider))) {
            object classInstance = Activator.CreateInstance(t);
            TaxProvider provider = (TaxProvider)classInstance;
            string name = provider.Name;
            ListItem item = new ListItem(name, name);
            ddlTaxProvider.Items.Add(item);
            if ((null != pcs) && (name == pcs.DefaultProvider)) {
                providerConfiguration.Provider = provider;
                providerConfiguration.DataBind();
                item.Selected = true;
            }
        }
    }

    protected void ddlTaxProvider_SelectedIndexChanged(object sender, EventArgs e) {
        providerConfiguration.Provider = GetSelectedProvider();
        providerConfiguration.DataBind();
    }

    private TaxProvider GetSelectedProvider() {
        foreach (Type t in Utils.GetProviders("*Tax*.dll", typeof(TaxProvider))) {
            object classInstance = Activator.CreateInstance(t);
            TaxProvider provider = (TaxProvider)classInstance;
            if (provider.Name == ddlTaxProvider.SelectedValue) {
                return provider;
            }
        }
        throw new ApplicationException("Internal Error: cannot find the selected tax provider");
    }

    protected void btnUpdate_Click(object sender, EventArgs e) {
        if (IsValid) {
            Dictionary<string, string> settings = providerConfiguration.GetSettings();
            TaxServiceConfigurationSection pcs = (TaxServiceConfigurationSection)ConfigurationController.SiteConfigurationController.GetSection(TaxServiceConfigurationSection.SectionName);
            if (null == pcs)
                pcs = new TaxServiceConfigurationSection();

            TaxProvider provider = GetSelectedProvider();
            ProviderSettings ps = new ProviderSettings(provider.Name, provider.GetType().AssemblyQualifiedName);
            if (null == pcs.Providers[provider.Name])
                pcs.Providers.Add(ps);

            foreach (string key in settings.Keys) {
                if (!string.IsNullOrEmpty(settings[key]))
                    pcs.Providers[provider.Name].Parameters[key] = settings[key];
            }
            pcs.DefaultProvider = provider.Name;

            ConfigurationController.SiteConfigurationController.SaveSection(TaxServiceConfigurationSection.SectionName, pcs);
            tlbUpdateProviderStatus.ShowText("Saved");
            InitControls();
        }
    }
}
