//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Core;
using DSC=DotShoppingCart.OpenSource.Core;

public partial class Controls_AddressInput : ValidatableUserControl {
    public override string ValidationGroup {
        set {
            base.ValidationGroup = value;
            FirstNameRequired.ValidationGroup = LastNameRequired.ValidationGroup
                = telPhone.ValidationGroup = value;
        }
    }

    public string PhoneNoticeText {
        get { return lblPhoneNotice.InnerText; }
        set {
            if (!string.IsNullOrEmpty(value)) {
                pnlPhoneNotice.Visible = true;
                lblPhoneNotice.InnerText = value;
            }
        }
    }

    public bool ShowNameFields {
        set { pnlName.Visible = value; }
    }

    public bool ShowSaveAs {
        set { pnlSaveAs.Visible = value; }
    }

    public string SaveAs {
        get { return txtSaveAs.Text.Trim(); }
    }

    public string FirstName {
        get { return txtFirstName.Text.Trim(); }
    }

    public string LastName {
        get { return txtLastName.Text.Trim(); }
    }

    public string CompanyName {
        get { return txtCompanyName.Text.Trim(); }
    }

    public string Address {
        get { return txtAddress.Text.Trim(); }
    }

    public string Address2 {
        get { return txtAddress2.Text.Trim(); }
    }

    public string City {
        get { return txtCity.Text.Trim(); }
    }

    public string State {
        get {
            if (string.IsNullOrEmpty(txtState.Text) || string.IsNullOrEmpty(ddlCountry.SelectedValue))
                return txtState.Text;
            return DSC.Address.GetStandardStateName(txtState.Text.Trim(), int.Parse(ddlCountry.SelectedValue)); 
        }
    }

    public int CountryId {
        get {
            if (string.IsNullOrEmpty(ddlCountry.SelectedValue))
                return 0;
            return int.Parse(ddlCountry.SelectedValue); }
    }

    public string Zipcode {
        get { return txtZipCode.Text.Trim(); }
    }

    public string Phone {
        get { return telPhone.Telephone; }
    }
    
    public string PhoneExt {
        get { return telPhone.Extension; }
    }

    public Address InitialAddressToDisplay {
        set {
            txtSaveAs.Text = value.SaveAs;
            txtFirstName.Text = value.FirstName;
            txtLastName.Text = value.LastName;
            txtCompanyName.Text = string.IsNullOrEmpty(value.CompanyName) ? string.Empty : value.CompanyName;
            txtAddress.Text = value.Address1;
            txtAddress2.Text = string.IsNullOrEmpty(value.Address2) ? string.Empty : value.Address2;
            txtCity.Text = value.City;
            txtState.Text = value.State;
            ddlCountry.SelectedValue = value.CountryId.ToString();
            txtZipCode.Text = value.Zipcode;
            telPhone.Telephone = value.Phone;
            telPhone.Extension = value.PhoneExt;
        }
    }

    public Address EnteredAddress {
        get {
            Address a = new Address(SaveAs, FirstName, LastName, CompanyName, Address, Address2,
                City, State, Zipcode, CountryId, Phone, PhoneExt);
            a.Country = Country.Get(CountryId);
            return a;
        }
    }

    private const string AddressChangedJavascriptBlockFormat = 
        "function AddressChanged() {{ " +
            "if (($get('{0}').value) && " +
            "($get('{1}').value) && " +
            "($get('{2}').value) && " +
            "($get('{3}').value)) " +
            "{4}();" +
            "}}";
    private string addressChangedJavacriptCallBack = null;
    public string AddressChangedJavacriptCallBack {
        set {
            txtAddress.Attributes.Add("onblur", "javascript:AddressChanged();");
            txtCity.Attributes.Add("onblur", "javascript:AddressChanged();");
            txtState.Attributes.Add("onblur", "javascript:AddressChanged();");
            ddlCountry.Attributes.Add("onblur", "javascript:AddressChanged();");
            txtZipCode.Attributes.Add("onblur", "javascript:AddressChanged();");
            addressChangedJavacriptCallBack = value;
        }
    }

    protected void Page_Load(object sender, EventArgs e) {
        if (null != addressChangedJavacriptCallBack) {
            ScriptManager.RegisterClientScriptBlock(this, typeof(Page), "AddressChanged",
                string.Format(AddressChangedJavascriptBlockFormat, txtAddress.ClientID, txtCity.ClientID, txtState.ClientID, txtZipCode.ClientID, addressChangedJavacriptCallBack), true);
        }
    }

    public void Clear() {
        txtSaveAs.Text = txtFirstName.Text = txtLastName.Text = txtCompanyName.Text = txtAddress.Text = txtAddress2.Text = txtCity.Text =
            txtState.Text = txtZipCode.Text = telPhone.Telephone = telPhone.Extension = string.Empty;
    }

    protected void cvdState_ServerValidate(object source, ServerValidateEventArgs args) {
        try {
            DSC.Address.GetStandardStateName(txtState.Text.Trim(), int.Parse(ddlCountry.SelectedValue));
            args.IsValid = true;
        } catch (ApplicationException) {
            args.IsValid = false;
        }
    }
}
