//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Core;

public class AddressSelectedEventArgs : EventArgs {
    public Address AddressSelected;

    public AddressSelectedEventArgs(Address selected) {
        AddressSelected = selected;
    }
}
public delegate void AddressMangerSelectEventHandler(object sender, AddressSelectedEventArgs e);

public partial class Controls_AddressManager : System.Web.UI.UserControl {
    private bool checkout;

    private bool editMode {
        get {
            object o = ViewState["editMode"];
            if (null == o)
                return false;
            return (bool)o;
        }

        set { ViewState["editMode"] = value; }
    }
    private Address addressForEditing {
        get { return (Address)ViewState["addressForEditing"]; }
        set { ViewState["addressForEditing"] = value; }
    }

    public bool Checkout {
        set { checkout = value; }
    }
    public event AddressMangerSelectEventHandler Selected = null;

    protected void Page_PreRender(object sender, EventArgs e) {
        btnAdd.Text = editMode ? "Update" : (checkout ? "Ship to this address" : "Add");
        btnCancel.Visible = editMode;

        dlAddress.DataSource = Address.GetShippingAddresses();
        dlAddress.DataBind();
    }

    protected void dlAddress_ItemDataBound(object sender, DataListItemEventArgs e) {
        if (e.Item.ItemType == ListItemType.Item ||
            e.Item.ItemType == ListItemType.AlternatingItem ||
            e.Item.ItemType == ListItemType.SelectedItem) {
            Address address = (Address)e.Item.DataItem;
            Button btnSelect = (Button)e.Item.FindControl("btnSelect");
            Button btnEdit = (Button)e.Item.FindControl("btnEdit");
            Button btnDelete = (Button)e.Item.FindControl("btnDelete");
            btnSelect.CommandArgument = btnEdit.CommandArgument = btnDelete.CommandArgument = address.AddressId.ToString();
            if (editMode) {
                btnSelect.Enabled = false;
                btnEdit.Enabled = false;
                btnDelete.Enabled = false;
            } else if (checkout) {
                btnSelect.Visible = true;
            }
        }
    }

    protected void btnAdd_Click(object sender, EventArgs e) {
        if (Page.IsValid) {
            if (editMode) {
                Address.Update(addressForEditing.AddressId, addressForEditing.IsDefaultShipping, aiNew.SaveAs, aiNew.FirstName, aiNew.LastName, aiNew.CompanyName, aiNew.Address, aiNew.Address2,
                    aiNew.City, aiNew.State, aiNew.Zipcode, aiNew.CountryId, aiNew.Phone, aiNew.PhoneExt);
                editMode = false;
            } else {
                int addedAddressId = Address.AddShippingAddress(aiNew.SaveAs, aiNew.FirstName, aiNew.LastName, aiNew.CompanyName, aiNew.Address, aiNew.Address2,
                    aiNew.City, aiNew.State, aiNew.Zipcode, aiNew.CountryId, aiNew.Phone, aiNew.PhoneExt);

                if (checkout)
                    SelectAddress(addedAddressId);
            }
            aiNew.Clear();
        }
    }

    protected void btnCancel_Click(object sender, EventArgs e) {
        editMode = false;
        aiNew.Clear();
    }

    protected void btnEdit_Command(object sender, CommandEventArgs e) {
        int addressId = int.Parse(e.CommandArgument.ToString());
        foreach (Address address in Address.GetShippingAddresses()) {
            if (address.AddressId == addressId) {
                aiNew.InitialAddressToDisplay = address;
                editMode = true;
                addressForEditing = address;
                break;
            }
        }
    }

    protected void btnDelete_Command(object sender, CommandEventArgs e) {
        int addressId = int.Parse(e.CommandArgument.ToString());
        Address.Delete(addressId);
    }
    

    protected void btnSelect_Command(object sender, CommandEventArgs e) {
        int addressId = int.Parse(e.CommandArgument.ToString());
        SelectAddress(addressId);
    }

    private void SelectAddress(int addressId) {
        Address.SetDefault(addressId);
        foreach (Address address in Address.GetShippingAddresses()) {
            if (address.AddressId == addressId) {
                // Update default address
                OnSelected(new AddressSelectedEventArgs(address));
            }
        }
    }

    protected virtual void OnSelected(AddressSelectedEventArgs e) {
        if (null != Selected) {
            Selected(this, e);
        }
    }
}
