﻿//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;
using System.Text.RegularExpressions;

using DotShoppingCart.OpenSource.Core;

public class BlockContainerSaveEventArgs : EventArgs {
    public BlockContainerData ContainerData;

    public BlockContainerSaveEventArgs(BlockContainerData containerData) {
        ContainerData = containerData;
    }
}
public delegate void BlockContainerSaveEventHandler(object sender, BlockContainerSaveEventArgs e);

public partial class Controls_Blocks_BlockContainer : BlockUserControl {
    [TemplateContainer(typeof(MenuContainer))]
    [PersistenceMode(PersistenceMode.InnerProperty)]
    public ITemplate MenuTemplate { get; set; }

    private MenuContainer container;
    public MenuContainer Menu {
        get { return container; }
    }

    public string Title {
        get { return lblBlockContainerTitle.Text; }
        set { lblBlockContainerTitle.Text = value; }
    }

    public int PageId { get; set; }

    public bool isPageRootContainer = false;
    public bool IsPageRootContainer {
        get { return isPageRootContainer; }
        set { isPageRootContainer = value; }
    }

    private List<KeyValuePair<string, string>> variables = new List<KeyValuePair<string,string>>();
    public List<KeyValuePair<string, string>> Variables {
        get { return variables; }
    }

    public event BlockContainerSaveEventHandler Save = null;

    private BlockContainerData blockContainerData;
    private Repeater rptVariables {
        get { return (Repeater)mdpEdit.Body.FindControl("rptVariables"); }
    }
    private TextBox txtBlockContainer {
        get { return (TextBox)mdpAdvanced.Body.FindControl("txtBlockContainer"); }
    }

    private TextBox txtBlockAlias {
        get { return (TextBox)mdpCreateAlias.Body.FindControl("txtBlockAlias"); }
    }

    private int masterColumnWidth = 0;
    private bool isFirstBlock = true;
    private Dictionary<int, int> blockIds = new Dictionary<int, int>();

    void Page_Init(object sender, EventArgs e) {
        if (null != MenuTemplate) {
            container = new MenuContainer();
            MenuTemplate.InstantiateIn(container);
            menuPlaceHolder.Controls.Add(container);
        }
    }

    protected void Page_Load(object sender, EventArgs e) {
        if (null != Data) {
            blockContainerData = Utils.FromXml<BlockContainerData>(Data.ToString());
            LoadContainerContent(blockContainerData.Content, !IsPostBack);

            if (WebUtils.IsPageEditorEnable() && (!EditorDisabled) && (!IsPostBack)) {
                pnlShowMenu.Visible = true;
                btnMoveForward.Visible = MoveForwardEnabled;
                btnMoveBack.Visible = MoveBackEnabled;
                btnDelete.Visible = DeleteEnabled;
                LoadEditor();
                ((RequiredFieldValidator)mdpCreateAlias.Body.FindControl("rfvBlockAlias")).ValidationGroup = mdpCreateAlias.ValidationGroup = string.Format("Alias_{0}", this.ClientID);
            }
        }
    }

    private void LoadEditor() {
        if (blockEditorDisabled) {
            mvwEditor.SetActiveView(vwEditorDisabled);
        } else {
            mvwEditor.SetActiveView(vwEditor);
            pnlBlockContainerContent.CssClass = "BlockEditPanel";
            if (string.IsNullOrEmpty(lblBlockContainerTitle.Text))
                lblBlockContainerTitle.Text = string.Format("Block Container {0}", BlockId);
            txtBlockContainer.Text = blockContainerData.Content;
            if (0 == variables.Count)
                btnEdit.Visible = false;
            else {
                rptVariables.DataSource = variables;
                rptVariables.DataBind();
            }
        }
    }

    private bool blockEditorDisabled {
        get {
            object o = Session[string.Format("BockEditor_{0}", BlockId)];
            if (null == o)
                return false;
            return (bool)o;
        }
        set { Session[string.Format("BockEditor_{0}", BlockId)] = value; }
    }

    private bool CheckCondition(XElement data) {
        if (null == data)
            return true;

        List<Condition> conditions = Utils.FromXml<List<Condition>>(data.ToString());
        foreach (Condition c in conditions) {
            bool b = bool.Parse(c.Value);
            switch (c.Property) {
                case "DiscountGroup":
                    if (WebUtils.IsDiscountGroup() != b)
                        return false;
                    break;
                case "HTTPS":
                    bool secureConnection = false;
                    if (null != HttpContext.Current)
                        secureConnection = HttpContext.Current.Request.IsSecureConnection;
                    if (secureConnection != b)
                        return false;
                    break;
            }
        }
        return true;
    }

    private void LoadContainerContent(string content, bool dataBind) {
        if (string.IsNullOrEmpty(content))
            return;
        BlockUserControl currentBlockControl = null;
        string[] parts = content.Split(new string[] { Constant.UI.ControlToken }, StringSplitOptions.RemoveEmptyEntries);
        foreach (string part in parts) {
            if (Regex.IsMatch(part, "^\\d+$")) { 
                //Block 
                int blockId = int.Parse(part);
                BlockUserControl buc = AddBlockToContainer(blockId, placeHolder);
                if (null != buc)
                    currentBlockControl = buc;
            } else if (part.StartsWith("width")) {
                string[] fields = part.Split(Constant.DB.ListSeparator);
                if (fields.Length >= 3)
                    variables.Add(new KeyValuePair<string, string>(fields[1], fields[2]));

                if (!string.IsNullOrEmpty(fields[2])) {
                    Literal l = new Literal();
                    l.Text = string.Format("width:{0};", fields[2]);
                    placeHolder.Controls.Add(l);

                    if ((ID == "masterContainerLeft") || (ID == "masterContainerRight")) {
                        string widthField = fields[2];
                        if (widthField.EndsWith("px", StringComparison.OrdinalIgnoreCase))
                            widthField = widthField.Substring(0, widthField.Length - 2);
                        int.TryParse(widthField, out masterColumnWidth);
                    }
                }
            } else if (part.StartsWith("BlockRef")) {
                string[] fields = part.Split(Constant.DB.ListSeparator);
                if (fields.Length >= 2) {
                    string blockReferenceName = fields[1];
                    int blockId = Block.GetBlockIdByBlockReferenceName(blockReferenceName);
                    BlockUserControl refControl = AddBlockToContainer(blockId, placeHolder);
                    refControl.MoveForwardEnabled = refControl.MoveBackEnabled = refControl.DeleteEnabled = false;
                    refControl.EditorDisabled = true;
                }
            } else {
                Match m = Regex.Match(part, "^PlaceHolder(\\d+)$");
                if (m.Success) {
                    if (WebUtils.IsPageEditorEnable() && (!EditorDisabled) && (!blockEditorDisabled)) {
                        Controls_Blocks_AddBlock addBlock = (Controls_Blocks_AddBlock)Page.LoadControl("~/Controls/Blocks/AddBlock.ascx");
                        addBlock.ID = string.Format("AddBlock{0}_PlaceHolder{1}", BlockId, m.Groups[1].Value);
                        addBlock.BlockId = BlockId;
                        addBlock.PlaceHolderName = string.Format("PlaceHolder{0}", m.Groups[1].Value);
                        if (null != BlockContainerType)
                            addBlock.BlockContainerType = BlockContainerType;
                        placeHolder.Controls.Add(addBlock);
                    }
                } else {
                    Literal l = new Literal();
                    l.Text = part;
                    placeHolder.Controls.Add(l);
                }
            }
        }
        if (null != currentBlockControl)
            currentBlockControl.MoveBackEnabled = false;
    }

    private string blockHeaderFormat = null;
    private string BlockHeaderFormat {
        get {
            if (null == blockHeaderFormat) {
                Block block = Block.GetByName("BlockHeaderFormat");
                BlockHeaderFormatData formatData = Utils.FromXml<BlockHeaderFormatData>(block.Data.ToString());
                blockHeaderFormat = formatData.Format;
            }
            return blockHeaderFormat;
        }
    }

    private BlockUserControl AddBlockToContainer(int blockId, Control containerControls) {
        Block block = Block.GetById(blockId);
        if ((WebUtils.IsPageEditorEnable() && (!blockEditorDisabled) && (!EditorDisabled)) || CheckCondition(block.Conditions)) {
            BlockUserControl buc = (BlockUserControl)LoadControl(block.BlockType.VirtualPath);
            if (blockIds.ContainsKey(blockId)) {
                blockIds[blockId]++;
                buc.ID = string.Format("Block_{0}_{1}", blockId, blockIds[blockId]);
            } else {
                blockIds.Add(blockId, 1);
                buc.ID = string.Format("Block_{0}", blockId);
            }
            buc.BlockId = blockId;
            buc.BlockContainerId = BlockId;
            if (null != BlockContainerType)
                buc.BlockContainerType = BlockContainerType;
            buc.Data = block.Data;
            if (isFirstBlock)
                isFirstBlock = buc.MoveForwardEnabled = false;
            buc.EditorDisabled = EditorDisabled || blockEditorDisabled;
            Control controlToAdd = buc;
            if ((null == block.HeaderData) && (masterColumnWidth > 0)) {
                //Enable block header by default when inside master columns
                block.HeaderData = new BlockHeaderData() {
                    Enabled = true,
                    Height = 27,
                    Title = block.BlockType.Type,
                    Width = masterColumnWidth
                }.ToXElement();
            }
            if (null != block.HeaderData) {
                buc.HeaderData = Utils.FromXml<BlockHeaderData>(block.HeaderData.ToString());
                if (buc.HeaderData.Enabled) {
                    HtmlGenericControl blockDiv = new HtmlGenericControl("div");
                    blockDiv.Attributes.Add("class", "block");
                    HtmlGenericControl header = new HtmlGenericControl("div");
                    header.Attributes.Add("class", "blockHeader");
                    header.Attributes.Add("style", string.Format(BlockHeaderFormat, buc.HeaderData.Height - 6, buc.HeaderData.Width, buc.HeaderData.Height));
                    header.InnerText = buc.HeaderData.Title;
                    blockDiv.Controls.Add(header);
                    blockDiv.Controls.Add(buc);
                    controlToAdd = blockDiv;
                }
            }
            containerControls.Controls.Add(controlToAdd);
            return buc;
        }
        return null;
    }

    protected void btnShowEditor_Click(object sender, EventArgs e) {
        blockEditorDisabled = false;
        WebUtils.ReloadPage();
    }

    protected void btnCloseEditor_Click(object sender, EventArgs e) {
        blockEditorDisabled = true;
        WebUtils.ReloadPage();
    }
    
    protected void mdpEdit_OkClick(object sender, EventArgs e) {
        if (rptVariables.Items.Count > 0) {
            string content = txtBlockContainer.Text;
            foreach (RepeaterItem item in rptVariables.Items) {
                Label lblName = (Label)item.FindControl("lblName");
                HiddenField hidOldValue = (HiddenField)item.FindControl("hidOldValue");
                TextBox txtValue = (TextBox)item.FindControl("txtValue");
                content = content.Replace(string.Format("{0}{1}{2}", lblName.Text, Constant.DB.ListSeparator, hidOldValue.Value),
                    string.Format("{0}{1}{2}", lblName.Text, Constant.DB.ListSeparator, txtValue.Text));
            }
            BlockContainerData data = new BlockContainerData();
            data.Content = content;
            SaveBlockContainerData(data);
        }
    }

    protected void mdpAdvanced_OkClick(object sender, EventArgs e) {
        BlockContainerData data = new BlockContainerData();
        data.Content = txtBlockContainer.Text;
        SaveBlockContainerData(data);
    }

    private void SaveBlockContainerData(BlockContainerData data) {
        if (null == Save)
            SaveData(data.ToXElement());
        else
            Save(this, new BlockContainerSaveEventArgs(data));
        Block.ClearCache();
        WebUtils.ReloadPage();
    }

    protected void btnDelete_Click(object sender, EventArgs e) {
        using (DSCDataContext dc = DBController.GetDataContext()) {
            if (IsPageRootContainer) {
                //remove blockContainer from page
                DbPage page = dc.DbPages.Single(p => p.PageId == PageId);
                page.BlockId = null;
            } else
                RemoveFromContainer(dc);
            BlockUserControl.DeleteBlockContainer(dc, BlockId);
            dc.SubmitChanges();
        }
        Block.ClearCache();
        WebUtils.ReloadPage();
    }

    protected void btnMoveForward_Click(object sender, EventArgs e) {
        MoveForward();
        Block.ClearCache();
        WebUtils.ReloadPage();
    }

    protected void btnMoveBack_Click(object sender, EventArgs e) {
        MoveBack();
        Block.ClearCache();
        WebUtils.ReloadPage();
    }

    protected void mdpCreateAlias_OkClick(object sender, EventArgs e) {
        if (Page.IsValid) {
            using (DSCDataContext dc = DBController.GetDataContext()) {
                var results = dc.BlockReferences.Where(b => b.BlockId == BlockId);
                if (results.Count() == 0) {
                    BlockReference br = new BlockReference();
                    br.BlockId = BlockId;
                    br.Name = txtBlockAlias.Text;
                    br.RefCount = 1;
                    dc.BlockReferences.InsertOnSubmit(br);
                    dc.SubmitChanges();
                    WebUtils.ReloadPage();
                } else {
                    BlockReference br = results.Single();
                    ScriptManager.RegisterStartupScript(this, typeof(Page), "BlockAliasExist",
                        string.Format("alert('Block Alias already exists. It's named as \"{0}\".')", br.Name), true);
                }
            }
        }
    }

    public class MenuContainer : Control, INamingContainer {
        internal MenuContainer() {
        }
    }

    public class BlockHeaderFormatData {
        public string Format;
    }
}
