﻿//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;

using DotShoppingCart.OpenSource.Core;

public partial class Controls_Blocks_Menu : BlockUserControl {
    protected MenuData menuData = MenuData.Default;
    private int totalMenuItems = 0;

    protected void Page_Load(object sender, EventArgs e) {
        EnableViewState = WebUtils.IsPageEditorEnable();
        editor.BlockUserControl = this;

        if (null != Data) {
            menuData = Utils.FromXml<MenuData>(Data.ToString());
        }

        if (null != menuData) {
            dvMenu.Attributes.Add("class", menuData.MenuClass);
            if (null != menuData.MenuItems)
                totalMenuItems = menuData.MenuItems.Count;
            rptMenu.DataSource = menuData.MenuItems;
            rptMenu.DataBind();
        }

        if ((null != HeaderData) && HeaderData.Enabled)
            pnlBlockContent.CssClass = "blockContent";
        if (ShowEditor) {
            pnlBlockContent.CssClass += " BlockEditPanel";
            editor.BlockTitle = string.Format("Menu {0}", BlockId);
        }
    }

    protected void editor_Editing(object sender, EventArgs e) {
        Response.Redirect(string.Format("{0}?id={1}&returnurl={2}",
            SiteNavigation.ResolveAbsoluteUrl(false, SiteNavigation.ResolveUrl("Admin/MenuEdit.aspx")), BlockId,
            Request.RawUrl));
    }

    protected bool IsCurrentPage(string link) {
        string rawUrl = SiteNavigation.GetRelativePathToApplicatonRoot(Page.Request.RawUrl);
        string linkUrl = SiteNavigation.GetRelativePathToApplicatonRoot(SiteNavigation.RemoveHostFromUrl(ResolveAbsoluteUrl(link)));
        return rawUrl.Equals(linkUrl, StringComparison.OrdinalIgnoreCase);
    }

    protected string ResolveAbsoluteUrl(string url) {
        if (string.IsNullOrEmpty(url))
            return null;
        if (url.StartsWith(@"http://", StringComparison.OrdinalIgnoreCase) ||
            url.StartsWith(@"https://", StringComparison.OrdinalIgnoreCase))
            return url;
        return SiteNavigation.ResolveAbsoluteUrl(false, SiteNavigation.ResolveUrlInText(url));
    }

    protected bool IsLastMenu(int index) {
        return totalMenuItems - 1 == index;
    }
}
