//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Core;

public partial class Controls_DateRange : System.Web.UI.UserControl {
    protected string validationGroup = null;
    private const int customIndex = 6;
    private bool skipSetSelected = false;

    public string ValidationGroup {
        get { return validationGroup; }
        set { validationGroup = value; }
    }
    
    public DateTime From {
        get {
            DateTime time = DateTime.Today;
            switch (ddlDateRangePicker.SelectedValue) {
                case "Today":
                    time = DateTime.Today;
                    break;
                case "Yesterday":
                    time = DateTime.Today.AddDays(-1);
                    break;
                case "Last 3 days":
                    time = DateTime.Today.AddDays(-3);
                    break;
                case "Last 7 days":
                    time = DateTime.Today.AddDays(-7);
                    break;
                case "Last Month":
                    time = new DateTime(DateTime.Today.Year, DateTime.Today.Month, 1).AddMonths(-1);
                    break;
                case "This Month":
                    time = new DateTime(DateTime.Today.Year, DateTime.Today.Month, 1);
                    break;
                case "Custom":
                    if (!DateTime.TryParse(txtFrom.Text, out time))
                        time = Constant.DB.DBDateTimeMinValue;
                    break;
            }
            return time;
        }
        set {
            ddlDateRangePicker.SelectedIndex = customIndex;
            txtFrom.Text = Constant.DB.DBDateTimeMinValue == value ? string.Empty : value.ToString();
            skipSetSelected = true;
        }
    }

    public DateTime To {
        get {
            DateTime time = DateTime.Today;
            switch (ddlDateRangePicker.SelectedValue) {
                case "Today":
                case "Last 3 days":
                case "Last 7 days":
                case "This Month":
                    time = DateTime.Today;
                    break;
                case "Yesterday":
                    time = DateTime.Today.AddDays(-1);
                    break;
                case "Last Month":
                    time = new DateTime(DateTime.Today.Year, DateTime.Today.Month, 1).AddDays(-1);
                    break;
                case "Custom":
                    if (!DateTime.TryParse(txtTo.Text, out time))
                        time = Constant.DB.DBDateTimeMaxValue;
                    break;
            }
            return time.AddSeconds(86399); // 24 * 60 * 60 - 1 seconds
        }
        set {
            ddlDateRangePicker.SelectedIndex = customIndex;
            txtTo.Text = Constant.DB.DBDateTimeMaxValue == value ? string.Empty : value.ToString();
            skipSetSelected = true;
        }
    }

    protected void Page_Load(object sender, EventArgs e) {
        if (!IsPostBack) {
            ddlDateRangePicker.Attributes.Add("onchange", "DateRangerPickerChanged(this.value)");
            LoadControlSettingsFromConfig();
        }
    }

    protected void Page_PreRender(object sender, EventArgs e) {
        if (!string.IsNullOrEmpty(validationGroup)) {
            foreach (Control control in Controls) {
                if (control is BaseValidator) {
                    ((BaseValidator)control).ValidationGroup = validationGroup;
                }
            }
        }

        if (IsPostBack) {
            WriteControlSettingsToConfig();
        }
    }
    
    protected void cvdDate_ServerValidate(object source, ServerValidateEventArgs args) {
        CustomValidator cvdDate = (CustomValidator)source;
        TextBox txtBox = (TextBox)FindControl(cvdDate.ControlToValidate);
        DateTime value;
        args.IsValid = DateTime.TryParse(txtBox.Text, out value);
    }

    private void LoadControlSettingsFromConfig() {
        if (!skipSetSelected) {
            string selected = WebUtils.GetCookie(this, "ddlDateRangePicker_selected");
            if (!string.IsNullOrEmpty(selected)) {
                WebUtils.SetDropDownListSelected(ddlDateRangePicker, selected);
                if ("Custom" == selected) {
                    string from = WebUtils.GetCookie(this, "ddlDateRangePicker_custom_from");
                    if (!string.IsNullOrEmpty(from))
                        txtFrom.Text = from;
                    string to = WebUtils.GetCookie(this, "ddlDateRangePicker_custom_to");
                    if (!string.IsNullOrEmpty(to))
                        txtTo.Text = to;
                }
            }
        }
    }

    private void WriteControlSettingsToConfig() {
        WebUtils.SetCookie(this, "ddlDateRangePicker_selected", ddlDateRangePicker.SelectedValue);
        if ("Custom" == ddlDateRangePicker.SelectedValue) {
            WebUtils.SetCookie(this, "ddlDateRangePicker_custom_from", txtFrom.Text);
            WebUtils.SetCookie(this, "ddlDateRangePicker_custom_to", txtTo.Text);
        }
    }
}
