//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using DotShoppingCart.OpenSource.Core;

public partial class Controls_DecimalTextBox : ValidatableUserControl {
    public string Name {
        get { return (string)ViewState["name"]; }
        set { ViewState["name"] = value; }
    }

    public bool Required {
        set { rfv.Visible = value; }
    }

    public string Text {
        get { return txtInput.Text; }
        set { txtInput.Text = value; }
    }

    public decimal Value {
        get { return decimal.Parse(txtInput.Text); }
        set { txtInput.Text = value.ToString(); }
    }

    public decimal MoneyValue {
        get { return Utils.Round(decimal.Parse(txtInput.Text)); }
        set { txtInput.Text = Utils.Round(value).ToString(); }
    }

    public Unit Width {
        get { return txtInput.Width; }
        set { txtInput.Width = value; }
    }

    public string MinimumValue {
        get { return rvdDecimal.MinimumValue; }
        set { 
            rvdDecimal.MinimumValue = value;
            rvdDecimal.Visible = true;
        }
    }

    public string MaximumValue {
        get { return rvdDecimal.MaximumValue; }
        set { 
            rvdDecimal.MaximumValue = value;
            rvdDecimal.Visible = true;
        }
    }

    protected void Page_PreRender(object sender, EventArgs e) {
        if (!IsPostBack) {
            rvdDecimal.ErrorMessage += string.Format("must be between {0} and {1}.", rvdDecimal.MinimumValue, rvdDecimal.MaximumValue);
        }

        if (!string.IsNullOrEmpty(Name)) {
            cvdDecimal.ErrorMessage = string.Format("{0} is not a valid decimal number.", Name);
            rfv.ErrorMessage = string.Format("{0} is required.", Name);
            rvdDecimal.ErrorMessage = string.Format("{0} must be between {1} and {2}.", Name, rvdDecimal.MinimumValue, rvdDecimal.MaximumValue);
        }
    }

    protected void cvdDecimal_ServerValidate(object source, ServerValidateEventArgs args) {
        CustomValidator cvd = (CustomValidator)source;
        TextBox txtInput = (TextBox)cvd.NamingContainer.FindControl(cvd.ControlToValidate);
        decimal value;
        args.IsValid = decimal.TryParse(txtInput.Text, out value);
    }
}
