﻿//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;
using System.Web.Caching;

using DotShoppingCart.OpenSource.Core;

public partial class Dynamic : DSCPage {
    private string pageConfigurationsCacheKey {
        get { return string.Format("pageConfigurations_{0}", SiteNavigation.GetHost()); }
    }

    private Dictionary<string, PageConfig> PageConfigurations {
        get {
            Dictionary<string, PageConfig> pageConfigurations;
            object o = Utils.Cache.Get(pageConfigurationsCacheKey);
            if (null == o) {
                pageConfigurations = new Dictionary<string, PageConfig>(StringComparer.OrdinalIgnoreCase);
                DynamicPageConfigurationSection section = DynamicPageConfigurationSection.GetSection();
                string defaultFormat = section.BlockContainerFormat.Value;
                foreach (PathConfigurationElement pathElement in section.Paths) {
                    string path = pathElement.Value;
                    foreach (PageConfigurationElement pageElement in pathElement.Pages) {
                        string format = string.IsNullOrEmpty(pageElement.BlockContainerFormat.Value) ? defaultFormat : pageElement.BlockContainerFormat.Value;
                        string pageName = (string.IsNullOrEmpty(path) ? "" : path + "/") + pageElement.Name;
                        string contentBlockName = string.Format("{0} Content", pageName);
                        Block contentBlock = Block.GetByName(contentBlockName,
                            new Block() { BlockTypeId = pageElement.BlockTypeId, Name = contentBlockName });
                        PageBlockContainerData defaultContainerData = new PageBlockContainerData() {
                            Content = string.Format(format, contentBlock.BlockId),
                            LeftMasterColumnDisabled = pageElement.IsLeftMasterColumnDisabled,
                            RightMasterColumnDisabled = pageElement.IsRightMasterColumnDisabled
                        };
                        Block defaultBlock = new Block() {
                            BlockTypeId = 1,
                            Name = string.Format("{0}.aspx", pageName),
                            Data = defaultContainerData.ToXElement()
                        };
                        pageConfigurations.Add(pageName,
                            new PageConfig() {
                                DefaultBlock = defaultBlock,
                                DefaultContainerData = defaultContainerData,
                                IsSecure = pageElement.IsSecure,
                                IsCustom = pageElement.IsCustomPage,
                                RequireRegistered = pageElement.RequireRegistered
                            });
                    }
                }

                Utils.Cache.Insert(pageConfigurationsCacheKey, pageConfigurations, null,
                    Cache.NoAbsoluteExpiration, new TimeSpan(1, 0, 0));
            } else {
                pageConfigurations = (Dictionary<string, PageConfig>)o;
            }

            return pageConfigurations;
        }
    }

    private PageConfig config = null;
    private string requestPath = null;

    protected void Page_PreInit(object sender, EventArgs e) {
        requestPath = Utils.GetParameter("p", null);
        if (string.IsNullOrEmpty(requestPath))
            Response.Redirect(SiteNavigation.Error404Page);

        if (!PageConfigurations.TryGetValue(requestPath, out config))
            Response.Redirect(SiteNavigation.Error404Page);

        this.IsSecure = config.IsSecure;
        this.IsCustomPage = config.IsCustom;
        this.RequireRegistered = config.RequireRegistered;
    }

    protected void Page_Load(object sender, EventArgs e) {
        Block block = Block.GetByName(requestPath + ".aspx", config.DefaultBlock);
        container.BlockId = block.BlockId;
        container.Data = block.Data;
        container.DefaultData = config.DefaultContainerData;
    }

    private class PageConfig {
        public PageBlockContainerData DefaultContainerData { get; set; }
        public Block DefaultBlock { get; set; }
        public bool IsSecure { get; set; }
        public bool IsCustom { get; set; }
        public bool RequireRegistered { get; set; }
    }
}
