//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Core;

public partial class Controls_AttributeSelection : System.Web.UI.UserControl {
    private List<ProductAttribute> attributes;
    private bool showOutofStock = false;

    public List<ProductAttribute> ProductAttributes {
        get { return attributes; }
        set { attributes = value; }
    }
    public bool ShowOutofStock {
        get { return showOutofStock; }
        set { showOutofStock = value; }
    }
    public List<int> SelectedAttributeValueIds {
        get {
            List<int> valueids = new List<int>();
            if (null != attributes) {
                foreach (ProductAttribute attrib in attributes) {
                    Control c = pnlAttributeControls.FindControl(attrib.Attribute.Name);
                    if (c is DropDownList) {
                        int valueid = int.Parse(((DropDownList)c).SelectedValue);
                        if (0 == valueid)
                            return null; // not selected
                        valueids.Add(valueid);
                    }
                }
            }
            return valueids;
        }
    }

    protected void Page_Load(object sender, EventArgs e) {
        LoadControls();
    }

    private void LoadControls() {
        if (null == attributes)
            return;

        foreach (ProductAttribute attrib in attributes) {
            Panel attribPanel = new Panel();
            attribPanel.Style.Add("padding-top", "20px");
            Label attribTitle = new Label();
            attribTitle.Text = string.Format("{0}{1}:", attrib.Attribute.IsRequired ? "<span class='error'>*</span> " : "", attrib.Attribute.Name);
            attribTitle.Style.Add("font-weight", "bold");
            if (!string.IsNullOrEmpty(attrib.Attribute.Description)) {
                attribTitle.Text += string.Format("<div class='smalltext'>{0}</div>", attrib.Attribute.Description);
            }
            attribTitle.Text += "<br />";
            attribPanel.Controls.Add(attribTitle);

            switch (attrib.Attribute.DisplayControl.Type) {
                case "DropDownList":
                    DropDownList ddl = new DropDownList();
                    ddl.ID = attrib.Attribute.Name;
                    ddl.Style.Add("padding", "10px, 0px, 10px, 0px");
                    ddl.AppendDataBoundItems = true;
                    ddl.Items.Add(new ListItem(string.Format(Constant.UI.SelectAttributeFormat, attrib.Attribute.Name), "0"));
                    ddl.DataSource = attrib.GetAvailableValues(showOutofStock);
                    ddl.DataTextField = "DisplayValue";
                    ddl.DataValueField = "ProductAttributeValueId";
                    ddl.DataBind();
                    ddl.SelectedIndex = 0;
                    ddl.Attributes.Add("onchange", string.Format("OnSelectionChange('{0}', this.options[this.selectedIndex].text)", attrib.Attribute.Name));

                    attribPanel.Controls.Add(ddl);
                    break;
                default:
                    throw new ApplicationException(string.Format("Control Type ({0}) is not implemented yet", attrib.Attribute.DisplayControl.Type));
            }

            /*
                case AttributeType.MultipleSelection:
                    lblSingle.Text += "<br>";
                    CheckBoxList chkList = new CheckBoxList();
                    chkList.ID = att.Name;
                    chkList.DataSource = att.Selections;
                    chkList.DataTextField = "Value";
                    chkList.DataValueField = "Value";
                    chkList.DataBind();
                    td.Controls.Add(chkList);
                    break;
                case AttributeType.UserInput:
                    lblSingle.Text += "<br>";
                    TextBox t = new TextBox();
                    t.ID = att.Name;
                    t.TextMode = TextBoxMode.MultiLine;
                    t.Height = Unit.Pixel(80);
                    t.Width = Unit.Pixel(120);
                    td.Controls.Add(t);

                    break;
*/
            pnlAttributeControls.Controls.Add(attribPanel);
        }
    }
}
