﻿//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;

using DotShoppingCart.OpenSource.Core;

public partial class Store_Blocks_CategoryList : BlockUserControl {
    private CheckBox chkShowProductCount {
        get { return (CheckBox)editor.Edit.FindControl("chkShowProductCount"); }
    }
    private Controls_NumberTextBox ntbImageWidth {
        get { return (Controls_NumberTextBox)editor.Edit.FindControl("ntbImageWidth"); }
    }
    private Controls_NumberTextBox ntbImageHeight {
        get { return (Controls_NumberTextBox)editor.Edit.FindControl("ntbImageHeight"); }
    }
    private ValidationSummary vdsEdit {
        get { return (ValidationSummary)editor.Edit.FindControl("vdsEdit"); }
    }

    protected string categoryUrl;
    protected CategoryListData categoryListData = CategoryListData.Default;

    protected void Page_Load(object sender, EventArgs e) {
        EnableViewState = WebUtils.IsPageEditorEnable();
        editor.BlockUserControl = this;

        if (null != Data) {
            categoryListData = Utils.FromXml<CategoryListData>(Data.ToString());
        }

        if ((null != HeaderData) && HeaderData.Enabled)
            pnlBlockContent.CssClass = "blockContent";
        if (ShowEditor) {
            pnlBlockContent.CssClass += " BlockEditPanel";
            editor.BlockTitle = string.Format("Category List {0}", BlockId);
            chkShowProductCount.Checked = categoryListData.ShowProductCount;
            ntbImageWidth.Value = categoryListData.ImageWidth;
            ntbImageHeight.Value = categoryListData.ImageHeight;
            vdsEdit.ValidationGroup = editor.ValidationGroup = ntbImageWidth.ValidationGroup = ntbImageHeight.ValidationGroup = this.ClientID;
        }

        Category[] categories;
        string requestPath = Utils.GetParameter("p", null);
        bool isCategoryPage = (!string.IsNullOrEmpty(requestPath)) &&
            (requestPath.Equals("Store/Category", StringComparison.OrdinalIgnoreCase) || requestPath.Equals("Category", StringComparison.OrdinalIgnoreCase));

        string categoryPath = isCategoryPage ? Utils.GetParameter("n", null) : null;
        if (string.IsNullOrEmpty(categoryPath)) {
            // root path
            categories = Category.GetCategories(0, 2);
        } else {
            Category current = Category.GetCategoryByCategoryPath(categoryPath);
            if (null == current)
                Response.Redirect(SiteNavigation.Error404Page);

            categories = new Category[] { current };
            // add root category to ease navigation
            rptRootCategoryies.DataSource = GetRootCategories(current);
            rptRootCategoryies.DataBind();
        }

        rptCategories.DataSource = categories;
        rptCategories.DataBind();

        if (categories.Length > 0) {
            categoryUrl = SiteNavigation.GetRewriterUrl("Category", categories[0].ParentFullPath, categories[0].Name);
            if (categories[0].ShowUsefulLinks && (categories[0].PriceRanges != null)) {
                pnlNarrowByPrice.Visible = true;
                rptPriceRange.DataSource = categories[0].PriceRanges;
                rptPriceRange.DataBind();
            }
            if (categories[0].ShowUsefulLinks && (categories[0].ManufacturerCounts != null)) {
                pnlNarrowByManufacturer.Visible = true;
                rptManufacturer.DataSource = categories[0].ManufacturerCounts;
                rptManufacturer.DataBind();
            }
        }
    }

    protected void editor_Save(object sender, EventArgs e) {
        CategoryListData data = new CategoryListData();
        data.ShowProductCount = chkShowProductCount.Checked;
        data.ImageWidth = ntbImageWidth.Value;
        data.ImageHeight = ntbImageHeight.Value;
        SaveData(data.ToXElement());
        Block.ClearCache();
        WebUtils.ReloadPage();
    }

    private List<Category> GetRootCategories(Category excludedCategory) {
        List<Category> categories = new List<Category>();
        foreach (Category c in Category.GetCategories(0, 2)) {
            if (excludedCategory.CategoryId != c.CategoryId)
                categories.Add(c);
        }
        return categories;
    }

    public class CategoryListData {
        public bool ShowProductCount { get; set; }
        public int ImageWidth { get; set; }
        public int ImageHeight { get; set; }

        public static readonly CategoryListData Default = new CategoryListData() {
            ShowProductCount = true,
            ImageWidth = 0,
            ImageHeight = 0
        };
    }
}
