﻿//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;

using DotShoppingCart.OpenSource.Core;

public partial class Store_Blocks_ProductList : BlockUserControl {
    private DropDownList ddlProductListType {
        get { return (DropDownList)editor.Edit.FindControl("ddlProductListType"); }
    }
    private Controls_NumberTextBox ntbProductCount {
        get { return (Controls_NumberTextBox)editor.Edit.FindControl("ntbProductCount"); }
    }
    private Controls_NumberTextBox ntbColumns {
        get { return (Controls_NumberTextBox)editor.Edit.FindControl("ntbColumns"); }
    }
    
    private ValidationSummary vdsEdit {
        get { return (ValidationSummary)editor.Edit.FindControl("vdsEdit"); }
    }

    protected ProductListData productListData = ProductListData.Default;

    protected void Page_Load(object sender, EventArgs e) {
        EnableViewState = WebUtils.IsPageEditorEnable();
        editor.BlockUserControl = this;

        if (null != Data) {
            productListData = Utils.FromXml<ProductListData>(Data.ToString());
        }

        if (ShowEditor) {
            pnlBlockContent.CssClass = "BlockEditPanel";
            editor.BlockTitle = string.Format("Product List {0}", BlockId);
            ntbProductCount.Value = productListData.ShowProductCount;
            ntbColumns.Value = productListData.ColumnCount;
            vdsEdit.ValidationGroup = editor.ValidationGroup = ntbProductCount.ValidationGroup = ntbColumns.ValidationGroup = this.ClientID;

            ddlProductListType.DataSource = ProductListTypeBinding.GetAll();
            ddlProductListType.DataBind();
            WebUtils.SetDropDownListSelected(ddlProductListType, productListData.Type.ToString());
        }

        productList.ProductItemsPerPage = productListData.ShowProductCount;
        productList.ColumnCount = productListData.ColumnCount;
        productList.Type = productListData.Type;
        productList.EditorDisabled = EditorDisabled;
        lblProductType.Text = string.Format("{0} Products", productList.Type);
    }

    protected void Page_PreRender(object sender, EventArgs e) {
        pnlProductList.Visible = productList.ProductCount > 0;
    }

    protected void editor_Save(object sender, EventArgs e) {
        ProductListData data = new ProductListData();
        data.ShowProductCount = ntbProductCount.Value;
        data.ColumnCount = ntbColumns.Value;
        data.Type = (ProductListType)Enum.Parse(typeof(ProductListType), ddlProductListType.SelectedValue);
        SaveData(data.ToXElement());
        Block.ClearCache();
        WebUtils.ReloadPage();
    }

    private class ProductListTypeBinding {
        public string Name { get; set; }
        public string Value { get; set; }

        public static List<ProductListTypeBinding> GetAll() {
            List<ProductListTypeBinding> all = new List<ProductListTypeBinding>();
            foreach (ProductListType type in Enum.GetValues(typeof(ProductListType))) {
                all.Add(new ProductListTypeBinding() {
                    Name = type.ToString() + " Products",
                    Value = type.ToString()
                });
            }
            return all;
        }
    }

    public class ProductListData {
        public ProductListType Type { get; set; }
        public int ShowProductCount { get; set; }
        public int ColumnCount { get; set; }

        public static readonly ProductListData Default = new ProductListData() {
            Type = ProductListType.Featured,
            ShowProductCount = 6,
            ColumnCount = 3
        };
    }
}