﻿//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;

using DotShoppingCart.OpenSource.Core;
using DotShoppingCart.OpenSource.Payment;

public partial class Store_Cart : BlockUserControl {
    private Cart cart = null;
    private Cart Cart {
        get {
            if (null == cart)
                cart = Cart.Get();
            return cart;
        }
    }

    protected ProductSummaryData productSummaryData;
    protected void Page_Load(object sender, EventArgs e) {
        if (!IsPostBack) {
            Block block = Block.GetByName(Constant.UI.ProductSummaryBlockName, ProductSummaryData.DefaultBlock);
            productSummaryData = Utils.FromXml<ProductSummaryData>(block.Data.ToString());
            BindControls();
            if (null != Cart) {
                UpdateTotals();
            }
            pnlCreditCardAndPaypal.Visible = IsCreditCardAndPaypalEnabled();
        }
    }

    private void BindControls() {
        ValidateStock();
        gvwCart.DataSource = null != Cart ? Cart.CartItems : null;
        gvwCart.DataBind();
        if (null != Cart) {
            lblSubTotal.Text = Cart.InstockSubTotal.ToString("C");
            if (WebUtils.IsDiscountGroup() && Cart.InstockSubTotal < WebUtils.GetMinOrderAmount()) {
                lblCheckout.CssClass = "success";
                lblCheckout.Text = string.Format("You are in a discount group and require minimum amount {0:C} to check out.", WebUtils.GetMinOrderAmount());
                btnCheckout.Enabled = false;
            }
        }
        pnlCheckout.Visible = pnlSubTotal.Visible = (null != Cart) && (!Cart.IsEmpty());
    }

    private bool IsCreditCardAndPaypalEnabled() {
        PaypalExpressPaymentProvider paypalExpressProvider = PaypalExpressPaymentProvider.GetProvider();
        PaypalStandardPaymentProvider paypalStandardProvider = PaypalStandardPaymentProvider.GetProvider();

        return (((null != paypalExpressProvider) && paypalExpressProvider.Enabled) ||
                ((null != paypalStandardProvider) && paypalStandardProvider.Enabled) ||
                (!(CreditCardPaymentService.GetProvider() is NullCreditCardPaymentProvider)));
    }

    private void ValidateStock() {
        Dictionary<int, int> cartItemIdQuantity = new Dictionary<int, int>();
        if ((null != Cart) && (null != Cart.CartItems)) {
            foreach (CartItem item in Cart.CartItems) {
                if (item.InstockQuantity < item.Quantity) {
                    cartItemIdQuantity.Add(item.CartItemId, item.InstockQuantity);
                }
            }
            if (cartItemIdQuantity.Count > 0) {
                Cart.UpdateItemQuantities(cartItemIdQuantity);
                lblNotice.Visible = true;
            }
        }
    }

    protected void btnUpdate_Click(object sender, EventArgs e) {
        Dictionary<int, int> cartItemIdQuantity = new Dictionary<int, int>();
        foreach (GridViewRow row in gvwCart.Rows) {
            Controls_NumberTextBox ntbQuantity = (Controls_NumberTextBox)row.FindControl("ntbQuantity");
            int qty;
            if (!int.TryParse(ntbQuantity.Text, out qty))
                qty = 0;
            cartItemIdQuantity.Add(int.Parse(gvwCart.DataKeys[row.DataItemIndex].Value.ToString()), qty);
        }
        Cart.UpdateItemQuantities(cartItemIdQuantity);
        WebUtils.ReloadPage();
    }

    protected void btnDelete_Click(object sender, EventArgs e) {
        foreach (GridViewRow row in gvwCart.Rows) {
            CheckBox chkSelect = (CheckBox)row.FindControl("chkSelect");
            if ((null != chkSelect) && chkSelect.Checked) {
                Cart.DeleteItem(int.Parse(gvwCart.DataKeys[row.DataItemIndex].Value.ToString()));
            }
        }
        WebUtils.ReloadPage();
    }

    protected void gvwCart_RowDataBound(object sender, GridViewRowEventArgs e) {
        if (DataControlRowType.DataRow == e.Row.RowType) {
            CartItem item = (CartItem)e.Row.DataItem;
            if (item.Product.SaveAmount > 0) {
                HtmlGenericControl divSaveAmount = (HtmlGenericControl)e.Row.FindControl("divSaveAmount");
                divSaveAmount.InnerHtml = string.Format("Your Save<br />{0:C}", item.Product.SaveAmount);
                divSaveAmount.Visible = true;
                HtmlGenericControl divSavePercentage = (HtmlGenericControl)e.Row.FindControl("divSavePercentage");
                divSavePercentage.InnerHtml = string.Format("({0:0%})", item.Product.SavePercentage);
                divSavePercentage.Visible = true;
            }
        }
    }

    private void UpdateTotals() {
        decimal grandTotal = Cart.SubTotal;
        lblGrandTotal.Text = string.Format("{0:C}", grandTotal);
        lblGrandTotal.CssClass = grandTotal >= 0 ? null : "negative";
    }

    protected void btnCheckout_Click(object sender, ImageClickEventArgs e) {
        Response.Redirect(SiteNavigation.CheckoutPage);
    }
}
