﻿//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;

using DotShoppingCart.OpenSource.Core;

public partial class Store_Category : BlockUserControl {
    private string categoryPath, manufacturer;
    private decimal? priceFrom, priceTo;
    private int totalNumber, pageNumber;
    private ProductSortBy sortby;
    private List<Product> products;
    private CategoryData categoryData = CategoryData.Default;

    private Controls_NumberTextBox ntbColumns {
        get { return (Controls_NumberTextBox)editor.Edit.FindControl("ntbColumns"); }
    }
    private Controls_NumberTextBox ntbProductCountPerPage {
        get { return (Controls_NumberTextBox)editor.Edit.FindControl("ntbProductCountPerPage"); }
    }
    private ValidationSummary vdsEdit {
        get { return (ValidationSummary)editor.Edit.FindControl("vdsEdit"); }
    }

    protected void Page_Load(object sender, EventArgs e) {
        EnableViewState = WebUtils.IsPageEditorEnable();
        ConfigureBlock();

        categoryPath = Utils.GetParameter("n");
        manufacturer = Utils.GetParameter("manufacturer", null);
        priceFrom = Utils.GetNullableDecimalParameter("pricefrom");
        priceTo = Utils.GetNullableDecimalParameter("priceto");
        pageNumber = Utils.GetIntParameter("page", 1);
        sortby = (ProductSortBy)Utils.GetIntParameter("sortby", 0);

        dlProducts.RepeatColumns = categoryData.Columns;
        products = Product.GetProducts(categoryPath, categoryData.ProductsPerPage,
            (pageNumber - 1) * categoryData.ProductsPerPage, sortby, manufacturer, priceFrom, priceTo,
            StoreConfigurationSection.GetSection().ShowStock,
            out totalNumber);
        BindControls();
    }

    private void BindControls() {
        dlProducts.DataSource = products;
        dlProducts.DataBind();
        if (0 == totalNumber) {
            plrTop.Visible = plrBottom.Visible = false;
            pnlEmpty.Visible = true;
        } else {
            plrTop.PageNumber = plrBottom.PageNumber = pageNumber;
            plrTop.TotalNumber = plrBottom.TotalNumber = totalNumber;
            plrTop.ProductsPerPage = plrBottom.ProductsPerPage = categoryData.ProductsPerPage;
        }
    }

    private void ConfigureBlock() {
        editor.BlockUserControl = this;
        editor.BlockUserControl.DeleteEnabled = false;

        if (null != Data) {
            categoryData = Utils.FromXml<CategoryData>(Data.ToString());
        }

        if (ShowEditor) {
            pnlBlockContent.CssClass = "BlockEditPanel";
            ntbColumns.Value = categoryData.Columns;
            ntbProductCountPerPage.Value = categoryData.ProductsPerPage;
            vdsEdit.ValidationGroup = editor.ValidationGroup = ntbColumns.ValidationGroup = ntbProductCountPerPage.ValidationGroup = this.ClientID;
        }
    }

    protected void editor_Save(object sender, EventArgs e) {
        CategoryData data = new CategoryData();
        data.Columns = ntbColumns.Value;
        data.ProductsPerPage = ntbProductCountPerPage.Value;
        SaveData(data.ToXElement());
        Block.ClearCache();
        WebUtils.ReloadPage();
    }

    public class CategoryData {
        public int Columns { get; set; }
        public int ProductsPerPage { get; set; }

        public static readonly CategoryData Default = new CategoryData() {
            Columns = 3,
            ProductsPerPage = 24
        };
    }
}
