//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Core;

public partial class Controls_PaymentSummary : System.Web.UI.UserControl {
    private CreditCard creditCard = null;
    public CreditCard CreditCard {
        get { return creditCard; }
        set { creditCard = value; }
    }

    private string customField = null;
    public string CustomField {
        get { return customField; }
        set { customField = value; }
    }

    private CheckoutPaymentTypeEnum checkoutPaymentType;
    public CheckoutPaymentTypeEnum CheckoutPaymentType {
        get { return checkoutPaymentType; }
        set { checkoutPaymentType = value; }
    }

    private bool showViewButton = false;
    public bool ShowViewButton {
        get { return showViewButton; }
        set { showViewButton = value; }
    }

    private int creditCardId {
        get { return (int)ViewState["creditCardId"]; }
        set { ViewState["creditCardId"] = value; }
    }

    protected void Page_Load(object sender, EventArgs e) {
        if (!Page.IsPostBack) {
            btnCancel.ImageUrl = FileController.GetFileUrl("close.gif");
            btnView.Visible = showViewButton && (CheckoutPaymentTypeEnum.CreditCard == checkoutPaymentType) &&
                Roles.IsUserInRole(Constant.Security.AdminRole);
        }
    }

    protected void Page_PreRender(object sender, EventArgs e) {
        if (null != creditCard)
            creditCardId = creditCard.CreditCardId;
        switch (checkoutPaymentType) {
            case CheckoutPaymentTypeEnum.CreditCard:
                mvwPayment.SetActiveView(vwCreditCard);
                Label lblCreditCard = (Label)mvwPayment.GetActiveView().FindControl("lblCreditCard");
                if (null == CreditCard) {
                    lblCreditCard.Text = "Credit Card";
                } else {
                    lblCreditCard.Text = string.Format("{0} : {1}<br />{2}/{3}", CreditCard.CreditCardType.Type, CreditCard.MaskedCardNumber,
                        CreditCard.ExpireMonth, CreditCard.ExpireYear);
                }
                break;
            case CheckoutPaymentTypeEnum.PaypalExpress:
                mvwPayment.SetActiveView(vwPaypalExpress);
                break;
            case CheckoutPaymentTypeEnum.GoogleCheckout:
                mvwPayment.SetActiveView(vwGoogleCheckout);
                if (!string.IsNullOrEmpty(customField)) {
                    Label lblGoogleOrderNumber = (Label)mvwPayment.FindControl("lblGoogleOrderNumber");
                    lblGoogleOrderNumber.Text = customField;
                }
                break;
            case CheckoutPaymentTypeEnum.Null:
                mvwPayment.SetActiveView(vwNull);
                break;
            case CheckoutPaymentTypeEnum.PaypalStandard:
                mvwPayment.SetActiveView(vwPaypalStandard);
                break;
        }
    }

    protected void btnOk_Click(object sender, EventArgs e) {
        if ("Ok" == btnOk.Text) {
            if (Page.IsValid) {
                mvwCreditCardView.ActiveViewIndex = 1;
                btnOk.Text = "Close";
                if (Membership.ValidateUser(Utils.GetUserName(), txtPassword.Text)) {
                    if (null == creditCard)
                        creditCard = CreditCard.Get(creditCardId);
                    lblFullCreditCardNumber.Text = CreditCard.CardNumber;
                } else {
                    lblFullCreditCardNumber.Text = "Invalid password";
                }
            }
        } else { //close
            mvwCreditCardView.ActiveViewIndex = 0;
            btnOk.Text = "Ok";
            lblFullCreditCardNumber.Text = string.Empty;
            mpeView.Hide();
        }
    }
}
