﻿//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;

using DotShoppingCart.OpenSource.Core;

public partial class Controls_Store_Product : BlockUserControl {
    private Product product;

    private DropDownList ddlProductDetailTemplate {
        get { return (DropDownList)editor.Edit.FindControl("ddlProductDetailTemplate"); }
    }

    protected void Page_Load(object sender, EventArgs e) {
        ConfigureBlock();

        string productSku = Utils.GetParameter("n", null);
        if (string.IsNullOrEmpty(productSku))
            throw new ApplicationException("n is required parameter");

        product = Product.Load(productSku);
        if (null == product)
            Response.Redirect(SiteNavigation.Error404Page);

        ProductDetail1.Product = product;
        ProductAction1.Product = product;
        ProductDescriptor1.Descriptors = product.ProductDescriptors;

        ProductAction1.AddingToCart += new ProductActionClickEventHandler(ProductAction1_AddingToCart);

        if (!IsPostBack) {
            int count = Utils.GetIntParameter("add", 0);
            if (count > 0) {
                List<int> attributeValueIds = new List<int>();
                foreach (ProductAttribute pa in product.ProductAttributes) {
                    string value = Utils.GetParameter(pa.Attribute.Name, null);
                    if (!string.IsNullOrEmpty(value)) {
                        value = Server.UrlDecode(value);
                        foreach (ProductAttributeValue pav in pa.Values) {
                            if (pav.Value.Equals(value, StringComparison.OrdinalIgnoreCase))
                                attributeValueIds.Add(pav.ProductAttributeValueId);
                        }
                    }
                }
                AddToCart(count, attributeValueIds);
            }
        }
    }

    private void ConfigureBlock() {
        editor.BlockUserControl = this;
        editor.BlockUserControl.DeleteEnabled = false;

        ProductData productData = ProductData.Default;
        if (null != Data) {
            productData = Utils.FromXml<ProductData>(Data.ToString());
        }
        ProductDetail1.Template = productData.Template;

        if (ShowEditor) {
            pnlBlockContent.CssClass = "BlockEditPanel";
            WebUtils.SetDropDownListSelected(ddlProductDetailTemplate, productData.Template);
        }
    }

    protected void editor_Save(object sender, EventArgs e) {
        ProductData data = new ProductData();
        data.Template = ddlProductDetailTemplate.SelectedValue;
        SaveData(data.ToXElement());
        Block.ClearCache();
        WebUtils.ReloadPage();
    }

    private void ProductAction1_AddingToCart(object sender, EventArgs e) {
        List<int> selectedAttributeValueIds = ProductDetail1.SelectedAttributeValueIds;
        if (null == selectedAttributeValueIds) {
            lblNotEnoughStock.Visible = true;
            return;
        }
        AddToCart(ProductAction1.Quantity, selectedAttributeValueIds);
    }

    private void AddToCart(int count, List<int> selectedAttributeValueIds) {
        int quantity = product.GetStockQuantity(count, selectedAttributeValueIds);
        if (0 == quantity)
            lblNotEnoughStock.Visible = true;
        else {
            int cartId = Cart.AddItem(Utils.GetUserName(), product.ProductId,
                Utils.GetSorted(selectedAttributeValueIds),
                quantity);
            Response.Redirect(string.Format("{0}?cartitemid={1}&quantity={2}", SiteNavigation.ItemAddedToCartPage, cartId, count));
        }
    }

    public class ProductData {
        public string Template { get; set; }

        public static readonly ProductData Default = new ProductData() {
            Template = "DefaultTemplate"
        };
    }
}
